
var CanvasKitInit = (() => {
  var _scriptName = import.meta.url;
  
  return (
function(moduleArg = {}) {
  var moduleRtn;

var q=moduleArg,aa,da,ea=new Promise((a,b)=>{aa=a;da=b}),fa="object"==typeof window,ha="function"==typeof importScripts;
(function(a){a.ce=a.ce||[];a.ce.push(function(){a.MakeSWCanvasSurface=function(b){var c=b,e="undefined"!==typeof OffscreenCanvas&&c instanceof OffscreenCanvas;if(!("undefined"!==typeof HTMLCanvasElement&&c instanceof HTMLCanvasElement||e||(c=document.getElementById(b),c)))throw"Canvas with id "+b+" was not found";if(b=a.MakeSurface(c.width,c.height))b.Ae=c;return b};a.MakeCanvasSurface||(a.MakeCanvasSurface=a.MakeSWCanvasSurface);a.MakeSurface=function(b,c){var e={width:b,height:c,colorType:a.ColorType.RGBA_8888,
alphaType:a.AlphaType.Unpremul,colorSpace:a.ColorSpace.SRGB},f=b*c*4,h=a._malloc(f);if(e=a.Surface._makeRasterDirect(e,h,4*b))e.Ae=null,e.bf=b,e.Ze=c,e.$e=f,e.Je=h,e.getCanvas().clear(a.TRANSPARENT);return e};a.MakeRasterDirectSurface=function(b,c,e){return a.Surface._makeRasterDirect(b,c.byteOffset,e)};a.Surface.prototype.flush=function(b){a.$d(this.Zd);this._flush();if(this.Ae){var c=new Uint8ClampedArray(a.HEAPU8.buffer,this.Je,this.$e);c=new ImageData(c,this.bf,this.Ze);b?this.Ae.getContext("2d").putImageData(c,
0,0,b[0],b[1],b[2]-b[0],b[3]-b[1]):this.Ae.getContext("2d").putImageData(c,0,0)}};a.Surface.prototype.dispose=function(){this.Je&&a._free(this.Je);this.delete()};a.$d=a.$d||function(){};a.De=a.De||function(){return null}})})(q);
(function(a){a.ce=a.ce||[];a.ce.push(function(){function b(h,l,p){return h&&h.hasOwnProperty(l)?h[l]:p}function c(h){var l=ja(ka);ka[l]=h;return l}function e(h,l,p,t){h.bindTexture(h.TEXTURE_2D,l);t||p.alphaType!==a.AlphaType.Premul||h.pixelStorei(h.UNPACK_PREMULTIPLY_ALPHA_WEBGL,!0);return l}function f(h,l,p){p||l.alphaType!==a.AlphaType.Premul||h.pixelStorei(h.UNPACK_PREMULTIPLY_ALPHA_WEBGL,!1);h.bindTexture(h.TEXTURE_2D,null)}a.GetWebGLContext=function(h,l){if(!h)throw"null canvas passed into makeWebGLContext";
var p={alpha:b(l,"alpha",1),depth:b(l,"depth",1),stencil:b(l,"stencil",8),antialias:b(l,"antialias",0),premultipliedAlpha:b(l,"premultipliedAlpha",1),preserveDrawingBuffer:b(l,"preserveDrawingBuffer",0),preferLowPowerToHighPerformance:b(l,"preferLowPowerToHighPerformance",0),failIfMajorPerformanceCaveat:b(l,"failIfMajorPerformanceCaveat",0),enableExtensionsByDefault:b(l,"enableExtensionsByDefault",1),explicitSwapControl:b(l,"explicitSwapControl",0),renderViaOffscreenBackBuffer:b(l,"renderViaOffscreenBackBuffer",
0)};p.majorVersion=l&&l.majorVersion?l.majorVersion:"undefined"!==typeof WebGL2RenderingContext?2:1;if(p.explicitSwapControl)throw"explicitSwapControl is not supported";h=la(h,p);if(!h)return 0;oa(h);z.le.getExtension("WEBGL_debug_renderer_info");return h};a.deleteContext=function(h){z===pa[h]&&(z=null);"object"==typeof JSEvents&&JSEvents.Cf(pa[h].le.canvas);pa[h]&&pa[h].le.canvas&&(pa[h].le.canvas.Xe=void 0);pa[h]=null};a._setTextureCleanup({deleteTexture:function(h,l){var p=ka[l];p&&pa[h].le.deleteTexture(p);
ka[l]=null}});a.MakeWebGLContext=function(h){if(!this.$d(h))return null;var l=this._MakeGrContext();if(!l)return null;l.Zd=h;var p=l.delete.bind(l);l["delete"]=function(){a.$d(this.Zd);p()}.bind(l);return z.Le=l};a.MakeGrContext=a.MakeWebGLContext;a.GrDirectContext.prototype.getResourceCacheLimitBytes=function(){a.$d(this.Zd);this._getResourceCacheLimitBytes()};a.GrDirectContext.prototype.getResourceCacheUsageBytes=function(){a.$d(this.Zd);this._getResourceCacheUsageBytes()};a.GrDirectContext.prototype.releaseResourcesAndAbandonContext=
function(){a.$d(this.Zd);this._releaseResourcesAndAbandonContext()};a.GrDirectContext.prototype.setResourceCacheLimitBytes=function(h){a.$d(this.Zd);this._setResourceCacheLimitBytes(h)};a.MakeOnScreenGLSurface=function(h,l,p,t,v,y){if(!this.$d(h.Zd))return null;l=void 0===v||void 0===y?this._MakeOnScreenGLSurface(h,l,p,t):this._MakeOnScreenGLSurface(h,l,p,t,v,y);if(!l)return null;l.Zd=h.Zd;return l};a.MakeRenderTarget=function(){var h=arguments[0];if(!this.$d(h.Zd))return null;if(3===arguments.length){var l=
this._MakeRenderTargetWH(h,arguments[1],arguments[2]);if(!l)return null}else if(2===arguments.length){if(l=this._MakeRenderTargetII(h,arguments[1]),!l)return null}else return null;l.Zd=h.Zd;return l};a.MakeWebGLCanvasSurface=function(h,l,p){l=l||null;var t=h,v="undefined"!==typeof OffscreenCanvas&&t instanceof OffscreenCanvas;if(!("undefined"!==typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||v||(t=document.getElementById(h),t)))throw"Canvas with id "+h+" was not found";h=this.GetWebGLContext(t,
p);if(!h||0>h)throw"failed to create webgl context: err "+h;h=this.MakeWebGLContext(h);l=this.MakeOnScreenGLSurface(h,t.width,t.height,l);return l?l:(l=t.cloneNode(!0),t.parentNode.replaceChild(l,t),l.classList.add("ck-replaced"),a.MakeSWCanvasSurface(l))};a.MakeCanvasSurface=a.MakeWebGLCanvasSurface;a.Surface.prototype.makeImageFromTexture=function(h,l){a.$d(this.Zd);h=c(h);if(l=this._makeImageFromTexture(this.Zd,h,l))l.ue=h;return l};a.Surface.prototype.makeImageFromTextureSource=function(h,l,p){l||=
{height:a.Be(h),width:a.Ce(h),colorType:a.ColorType.RGBA_8888,alphaType:p?a.AlphaType.Premul:a.AlphaType.Unpremul};l.colorSpace||(l.colorSpace=a.ColorSpace.SRGB);a.$d(this.Zd);var t=z.le;p=e(t,t.createTexture(),l,p);2===z.version?t.texImage2D(t.TEXTURE_2D,0,t.RGBA,l.width,l.height,0,t.RGBA,t.UNSIGNED_BYTE,h):t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,h);f(t,l);this._resetContext();return this.makeImageFromTexture(p,l)};a.Surface.prototype.updateTextureFromSource=function(h,l,p){if(h.ue){a.$d(this.Zd);
var t=h.getImageInfo(),v=z.le,y=e(v,ka[h.ue],t,p);2===z.version?v.texImage2D(v.TEXTURE_2D,0,v.RGBA,a.Ce(l),a.Be(l),0,v.RGBA,v.UNSIGNED_BYTE,l):v.texImage2D(v.TEXTURE_2D,0,v.RGBA,v.RGBA,v.UNSIGNED_BYTE,l);f(v,t,p);this._resetContext();ka[h.ue]=null;h.ue=c(y);t.colorSpace=h.getColorSpace();l=this._makeImageFromTexture(this.Zd,h.ue,t);p=h.Yd.ae;v=h.Yd.ee;h.Yd.ae=l.Yd.ae;h.Yd.ee=l.Yd.ee;l.Yd.ae=p;l.Yd.ee=v;l.delete();t.colorSpace.delete()}};a.MakeLazyImageFromTextureSource=function(h,l,p){l||={height:a.Be(h),
width:a.Ce(h),colorType:a.ColorType.RGBA_8888,alphaType:p?a.AlphaType.Premul:a.AlphaType.Unpremul};l.colorSpace||(l.colorSpace=a.ColorSpace.SRGB);var t={makeTexture:function(){var v=z,y=v.le,C=e(y,y.createTexture(),l,p);2===v.version?y.texImage2D(y.TEXTURE_2D,0,y.RGBA,l.width,l.height,0,y.RGBA,y.UNSIGNED_BYTE,h):y.texImage2D(y.TEXTURE_2D,0,y.RGBA,y.RGBA,y.UNSIGNED_BYTE,h);f(y,l,p);return c(C)},freeSrc:function(){}};"VideoFrame"===h.constructor.name&&(t.freeSrc=function(){h.close()});return a.Image._makeFromGenerator(l,
t)};a.$d=function(h){return h?oa(h):!1};a.De=function(){return z&&z.Le&&!z.Le.isDeleted()?z.Le:null}})})(q);
(function(a){function b(g){return(f(255*g[3])<<24|f(255*g[0])<<16|f(255*g[1])<<8|f(255*g[2])<<0)>>>0}function c(g){if(g&&g._ck)return g;if(g instanceof Float32Array){for(var d=Math.floor(g.length/4),k=new Uint32Array(d),m=0;m<d;m++)k[m]=b(g.slice(4*m,4*(m+1)));return k}if(g instanceof Uint32Array)return g;if(g instanceof Array&&g[0]instanceof Float32Array)return g.map(b)}function e(g){if(void 0===g)return 1;var d=parseFloat(g);return g&&-1!==g.indexOf("%")?d/100:d}function f(g){return Math.round(Math.max(0,
Math.min(g||0,255)))}function h(g,d){d&&d._ck||a._free(g)}function l(g,d,k){if(!g||!g.length)return K;if(g&&g._ck)return g.byteOffset;var m=a[d].BYTES_PER_ELEMENT;k||=a._malloc(g.length*m);a[d].set(g,k/m);return k}function p(g){var d={he:K,count:g.length,colorType:a.ColorType.RGBA_F32};if(g instanceof Float32Array)d.he=l(g,"HEAPF32"),d.count=g.length/4;else if(g instanceof Uint32Array)d.he=l(g,"HEAPU32"),d.colorType=a.ColorType.RGBA_8888;else if(g instanceof Array){if(g&&g.length){for(var k=a._malloc(16*
g.length),m=0,r=k/4,u=0;u<g.length;u++)for(var x=0;4>x;x++)a.HEAPF32[r+m]=g[u][x],m++;g=k}else g=K;d.he=g}else throw"Invalid argument to copyFlexibleColorArray, Not a color array "+typeof g;return d}function t(g){if(!g)return K;var d=ba.toTypedArray();if(g.length){if(6===g.length||9===g.length)return l(g,"HEAPF32",Q),6===g.length&&a.HEAPF32.set(Wc,6+Q/4),Q;if(16===g.length)return d[0]=g[0],d[1]=g[1],d[2]=g[3],d[3]=g[4],d[4]=g[5],d[5]=g[7],d[6]=g[12],d[7]=g[13],d[8]=g[15],Q;throw"invalid matrix size";
}if(void 0===g.m11)throw"invalid matrix argument";d[0]=g.m11;d[1]=g.m21;d[2]=g.m41;d[3]=g.m12;d[4]=g.m22;d[5]=g.m42;d[6]=g.m14;d[7]=g.m24;d[8]=g.m44;return Q}function v(g){if(!g)return K;var d=Y.toTypedArray();if(g.length){if(16!==g.length&&6!==g.length&&9!==g.length)throw"invalid matrix size";if(16===g.length)return l(g,"HEAPF32",ma);d.fill(0);d[0]=g[0];d[1]=g[1];d[3]=g[2];d[4]=g[3];d[5]=g[4];d[7]=g[5];d[10]=1;d[12]=g[6];d[13]=g[7];d[15]=g[8];6===g.length&&(d[12]=0,d[13]=0,d[15]=1);return ma}if(void 0===
g.m11)throw"invalid matrix argument";d[0]=g.m11;d[1]=g.m21;d[2]=g.m31;d[3]=g.m41;d[4]=g.m12;d[5]=g.m22;d[6]=g.m32;d[7]=g.m42;d[8]=g.m13;d[9]=g.m23;d[10]=g.m33;d[11]=g.m43;d[12]=g.m14;d[13]=g.m24;d[14]=g.m34;d[15]=g.m44;return ma}function y(g,d){return l(g,"HEAPF32",d||ia)}function C(g,d,k,m){var r=Fa.toTypedArray();r[0]=g;r[1]=d;r[2]=k;r[3]=m;return ia}function H(g){for(var d=new Float32Array(4),k=0;4>k;k++)d[k]=a.HEAPF32[g/4+k];return d}function I(g,d){return l(g,"HEAPF32",d||V)}function R(g,d){return l(g,
"HEAPF32",d||ub)}a.Color=function(g,d,k,m){void 0===m&&(m=1);return a.Color4f(f(g)/255,f(d)/255,f(k)/255,m)};a.ColorAsInt=function(g,d,k,m){void 0===m&&(m=255);return(f(m)<<24|f(g)<<16|f(d)<<8|f(k)<<0&268435455)>>>0};a.Color4f=function(g,d,k,m){void 0===m&&(m=1);return Float32Array.of(g,d,k,m)};Object.defineProperty(a,"TRANSPARENT",{get:function(){return a.Color4f(0,0,0,0)}});Object.defineProperty(a,"BLACK",{get:function(){return a.Color4f(0,0,0,1)}});Object.defineProperty(a,"WHITE",{get:function(){return a.Color4f(1,
1,1,1)}});Object.defineProperty(a,"RED",{get:function(){return a.Color4f(1,0,0,1)}});Object.defineProperty(a,"GREEN",{get:function(){return a.Color4f(0,1,0,1)}});Object.defineProperty(a,"BLUE",{get:function(){return a.Color4f(0,0,1,1)}});Object.defineProperty(a,"YELLOW",{get:function(){return a.Color4f(1,1,0,1)}});Object.defineProperty(a,"CYAN",{get:function(){return a.Color4f(0,1,1,1)}});Object.defineProperty(a,"MAGENTA",{get:function(){return a.Color4f(1,0,1,1)}});a.getColorComponents=function(g){return[Math.floor(255*
g[0]),Math.floor(255*g[1]),Math.floor(255*g[2]),g[3]]};a.parseColorString=function(g,d){g=g.toLowerCase();if(g.startsWith("#")){d=255;switch(g.length){case 9:d=parseInt(g.slice(7,9),16);case 7:var k=parseInt(g.slice(1,3),16);var m=parseInt(g.slice(3,5),16);var r=parseInt(g.slice(5,7),16);break;case 5:d=17*parseInt(g.slice(4,5),16);case 4:k=17*parseInt(g.slice(1,2),16),m=17*parseInt(g.slice(2,3),16),r=17*parseInt(g.slice(3,4),16)}return a.Color(k,m,r,d/255)}return g.startsWith("rgba")?(g=g.slice(5,
-1),g=g.split(","),a.Color(+g[0],+g[1],+g[2],e(g[3]))):g.startsWith("rgb")?(g=g.slice(4,-1),g=g.split(","),a.Color(+g[0],+g[1],+g[2],e(g[3]))):g.startsWith("gray(")||g.startsWith("hsl")||!d||(g=d[g],void 0===g)?a.BLACK:g};a.multiplyByAlpha=function(g,d){g=g.slice();g[3]=Math.max(0,Math.min(g[3]*d,1));return g};a.Malloc=function(g,d){var k=a._malloc(d*g.BYTES_PER_ELEMENT);return{_ck:!0,length:d,byteOffset:k,qe:null,subarray:function(m,r){m=this.toTypedArray().subarray(m,r);m._ck=!0;return m},toTypedArray:function(){if(this.qe&&
this.qe.length)return this.qe;this.qe=new g(a.HEAPU8.buffer,k,d);this.qe._ck=!0;return this.qe}}};a.Free=function(g){a._free(g.byteOffset);g.byteOffset=K;g.toTypedArray=null;g.qe=null};var Q=K,ba,ma=K,Y,ia=K,Fa,ca,V=K,Vb,Ba=K,Wb,vb=K,Xb,wb=K,ab,Na=K,Yb,ub=K,Zb,$b=K,Wc=Float32Array.of(0,0,1),K=0;a.Ce=function(g){return g.naturalWidth||g.videoWidth||g.displayWidth||g.width};a.Be=function(g){return g.naturalHeight||g.videoHeight||g.displayHeight||g.height};a.onRuntimeInitialized=function(){function g(d,
k,m,r,u,x,B){x||(x=4*r.width,r.colorType===a.ColorType.RGBA_F16?x*=2:r.colorType===a.ColorType.RGBA_F32&&(x*=4));var F=x*r.height;var E=u?u.byteOffset:a._malloc(F);if(B?!d._readPixels(r,E,x,k,m,B):!d._readPixels(r,E,x,k,m))return u||a._free(E),null;if(u)return u.toTypedArray();switch(r.colorType){case a.ColorType.RGBA_8888:case a.ColorType.RGBA_F16:d=(new Uint8Array(a.HEAPU8.buffer,E,F)).slice();break;case a.ColorType.RGBA_F32:d=(new Float32Array(a.HEAPU8.buffer,E,F)).slice();break;default:return null}a._free(E);
return d}Fa=a.Malloc(Float32Array,4);ia=Fa.byteOffset;Y=a.Malloc(Float32Array,16);ma=Y.byteOffset;ba=a.Malloc(Float32Array,9);Q=ba.byteOffset;Yb=a.Malloc(Float32Array,12);ub=Yb.byteOffset;Zb=a.Malloc(Float32Array,12);$b=Zb.byteOffset;ca=a.Malloc(Float32Array,4);V=ca.byteOffset;Vb=a.Malloc(Float32Array,4);Ba=Vb.byteOffset;Wb=a.Malloc(Float32Array,3);vb=Wb.byteOffset;Xb=a.Malloc(Float32Array,3);wb=Xb.byteOffset;ab=a.Malloc(Int32Array,4);Na=ab.byteOffset;a.ColorSpace.SRGB=a.ColorSpace._MakeSRGB();a.ColorSpace.DISPLAY_P3=
a.ColorSpace._MakeDisplayP3();a.ColorSpace.ADOBE_RGB=a.ColorSpace._MakeAdobeRGB();a.GlyphRunFlags={IsWhiteSpace:a._GlyphRunFlags_isWhiteSpace};a.Path.MakeFromCmds=function(d){var k=l(d,"HEAPF32"),m=a.Path._MakeFromCmds(k,d.length);h(k,d);return m};a.Path.MakeFromVerbsPointsWeights=function(d,k,m){var r=l(d,"HEAPU8"),u=l(k,"HEAPF32"),x=l(m,"HEAPF32"),B=a.Path._MakeFromVerbsPointsWeights(r,d.length,u,k.length/2,x,m&&m.length||0);h(r,d);h(u,k);h(x,m);return B};a.PathBuilder.prototype.addArc=function(d,
k,m){d=I(d);this._addArc(d,k,m);return this};a.PathBuilder.prototype.addCircle=function(d,k,m,r){this._addCircle(d,k,m,!!r);return this};a.PathBuilder.prototype.addOval=function(d,k,m){void 0===m&&(m=1);d=I(d);this._addOval(d,!!k,m);return this};a.PathBuilder.prototype.addPath=function(){var d=Array.prototype.slice.call(arguments),k=d[0],m=!1;"boolean"===typeof d[d.length-1]&&(m=d.pop());if(1===d.length)this._addPath(k,1,0,0,0,1,0,0,0,1,m);else if(2===d.length)d=d[1],this._addPath(k,d[0],d[1],d[2],
d[3],d[4],d[5],d[6]||0,d[7]||0,d[8]||1,m);else if(7===d.length||10===d.length)this._addPath(k,d[1],d[2],d[3],d[4],d[5],d[6],d[7]||0,d[8]||0,d[9]||1,m);else return null;return this};a.PathBuilder.prototype.addPolygon=function(d,k){var m=l(d,"HEAPF32");this._addPolygon(m,d.length/2,k);h(m,d);return this};a.PathBuilder.prototype.addRect=function(d,k){d=I(d);this._addRect(d,!!k);return this};a.PathBuilder.prototype.addRRect=function(d,k){d=R(d);this._addRRect(d,!!k);return this};a.PathBuilder.prototype.addVerbsPointsWeights=
function(d,k,m){var r=l(d,"HEAPU8"),u=l(k,"HEAPF32"),x=l(m,"HEAPF32");this._addVerbsPointsWeights(r,d.length,u,k.length/2,x,m&&m.length||0);h(r,d);h(u,k);h(x,m);return this};a.PathBuilder.prototype.arc=function(d,k,m,r,u,x){d=a.LTRBRect(d-m,k-m,d+m,k+m);u=(u-r)/Math.PI*180-360*!!x;r=(new a.PathBuilder).addArc(d,r/Math.PI*180,u).detachAndDelete();this.addPath(r,!0);r.delete();return this};a.PathBuilder.prototype.arcToOval=function(d,k,m,r){d=I(d);this._arcToOval(d,k,m,r);return this};a.PathBuilder.prototype.arcToRotated=
function(d,k,m,r,u,x,B){this._arcToRotated(d,k,m,!!r,!!u,x,B);return this};a.PathBuilder.prototype.arcToTangent=function(d,k,m,r,u){this._arcToTangent(d,k,m,r,u);return this};a.PathBuilder.prototype.close=function(){this._close();return this};a.PathBuilder.prototype.conicTo=function(d,k,m,r,u){this._conicTo(d,k,m,r,u);return this};a.Path.prototype.computeTightBounds=function(d){this._computeTightBounds(V);var k=ca.toTypedArray();return d?(d.set(k),d):k.slice()};a.PathBuilder.prototype.cubicTo=function(d,
k,m,r,u,x){this._cubicTo(d,k,m,r,u,x);return this};a.PathBuilder.prototype.detachAndDelete=function(){var d=this.detach();this.delete();return d};a.Path.prototype.getBounds=function(d){this._getBounds(V);var k=ca.toTypedArray();return d?(d.set(k),d):k.slice()};a.PathBuilder.prototype.getBounds=function(d){this._getBounds(V);var k=ca.toTypedArray();return d?(d.set(k),d):k.slice()};a.PathBuilder.prototype.lineTo=function(d,k){this._lineTo(d,k);return this};a.PathBuilder.prototype.moveTo=function(d,
k){this._moveTo(d,k);return this};a.PathBuilder.prototype.offset=function(d,k){this._transform(1,0,d,0,1,k,0,0,1);return this};a.PathBuilder.prototype.quadTo=function(d,k,m,r){this._quadTo(d,k,m,r);return this};a.PathBuilder.prototype.rArcTo=function(d,k,m,r,u,x,B){this._rArcTo(d,k,m,r,u,x,B);return this};a.PathBuilder.prototype.rConicTo=function(d,k,m,r,u){this._rConicTo(d,k,m,r,u);return this};a.PathBuilder.prototype.rCubicTo=function(d,k,m,r,u,x){this._rCubicTo(d,k,m,r,u,x);return this};a.PathBuilder.prototype.rLineTo=
function(d,k){this._rLineTo(d,k);return this};a.PathBuilder.prototype.rMoveTo=function(d,k){this._rMoveTo(d,k);return this};a.PathBuilder.prototype.rQuadTo=function(d,k,m,r){this._rQuadTo(d,k,m,r);return this};a.PathBuilder.prototype.setFillType=function(d){this._setFillType(d);return this};a.Path.prototype.makeStroked=function(d){d=d||{};d.width=d.width||1;d.miter_limit=d.miter_limit||4;d.cap=d.cap||a.StrokeCap.Butt;d.join=d.join||a.StrokeJoin.Miter;d.precision=d.precision||1;return this._makeStroked(d)};
a.PathBuilder.prototype.transform=function(){if(1===arguments.length){var d=arguments[0];this._transform(d[0],d[1],d[2],d[3],d[4],d[5],d[6]||0,d[7]||0,d[8]||1)}else if(6===arguments.length||9===arguments.length)d=arguments,this._transform(d[0],d[1],d[2],d[3],d[4],d[5],d[6]||0,d[7]||0,d[8]||1);else throw"transform expected to take 1 or 9 arguments. Got "+arguments.length;return this};a.Path.prototype.makeTrimmed=function(d,k,m){return this._makeTrimmed(d,k,!!m)};a.Image.prototype.encodeToBytes=function(d,
k){var m=a.De();d=d||a.ImageFormat.PNG;k=k||100;return m?this._encodeToBytes(d,k,m):this._encodeToBytes(d,k)};a.Image.prototype.makeShaderCubic=function(d,k,m,r,u){u=t(u);return this._makeShaderCubic(d,k,m,r,u)};a.Image.prototype.makeShaderOptions=function(d,k,m,r,u){u=t(u);return this._makeShaderOptions(d,k,m,r,u)};a.Image.prototype.readPixels=function(d,k,m,r,u){var x=a.De();return g(this,d,k,m,r,u,x)};a.Canvas.prototype.clear=function(d){a.$d(this.Zd);d=y(d);this._clear(d)};a.Canvas.prototype.clipRRect=
function(d,k,m){a.$d(this.Zd);d=R(d);this._clipRRect(d,k,m)};a.Canvas.prototype.clipRect=function(d,k,m){a.$d(this.Zd);d=I(d);this._clipRect(d,k,m)};a.Canvas.prototype.concat=function(d){a.$d(this.Zd);d=v(d);this._concat(d)};a.Canvas.prototype.drawArc=function(d,k,m,r,u){a.$d(this.Zd);d=I(d);this._drawArc(d,k,m,r,u)};a.Canvas.prototype.drawAtlas=function(d,k,m,r,u,x,B){if(d&&r&&k&&m&&k.length===m.length){a.$d(this.Zd);u||(u=a.BlendMode.SrcOver);var F=l(k,"HEAPF32"),E=l(m,"HEAPF32"),T=m.length/4,U=
l(c(x),"HEAPU32");if(B&&"B"in B&&"C"in B)this._drawAtlasCubic(d,E,F,U,T,u,B.B,B.C,r);else{let n=a.FilterMode.Linear,w=a.MipmapMode.None;B&&(n=B.filter,"mipmap"in B&&(w=B.mipmap));this._drawAtlasOptions(d,E,F,U,T,u,n,w,r)}h(F,k);h(E,m);h(U,x)}};a.Canvas.prototype.drawCircle=function(d,k,m,r){a.$d(this.Zd);this._drawCircle(d,k,m,r)};a.Canvas.prototype.drawColor=function(d,k){a.$d(this.Zd);d=y(d);void 0!==k?this._drawColor(d,k):this._drawColor(d)};a.Canvas.prototype.drawColorInt=function(d,k){a.$d(this.Zd);
this._drawColorInt(d,k||a.BlendMode.SrcOver)};a.Canvas.prototype.drawColorComponents=function(d,k,m,r,u){a.$d(this.Zd);d=C(d,k,m,r);void 0!==u?this._drawColor(d,u):this._drawColor(d)};a.Canvas.prototype.drawDRRect=function(d,k,m){a.$d(this.Zd);d=R(d,ub);k=R(k,$b);this._drawDRRect(d,k,m)};a.Canvas.prototype.drawImage=function(d,k,m,r){a.$d(this.Zd);this._drawImage(d,k,m,r||null)};a.Canvas.prototype.drawImageCubic=function(d,k,m,r,u,x){a.$d(this.Zd);this._drawImageCubic(d,k,m,r,u,x||null)};a.Canvas.prototype.drawImageOptions=
function(d,k,m,r,u,x){a.$d(this.Zd);this._drawImageOptions(d,k,m,r,u,x||null)};a.Canvas.prototype.drawImageNine=function(d,k,m,r,u){a.$d(this.Zd);k=l(k,"HEAP32",Na);m=I(m);this._drawImageNine(d,k,m,r,u||null)};a.Canvas.prototype.drawImageRect=function(d,k,m,r,u){a.$d(this.Zd);I(k,V);I(m,Ba);this._drawImageRect(d,V,Ba,r,!!u)};a.Canvas.prototype.drawImageRectCubic=function(d,k,m,r,u,x){a.$d(this.Zd);I(k,V);I(m,Ba);this._drawImageRectCubic(d,V,Ba,r,u,x||null)};a.Canvas.prototype.drawImageRectOptions=
function(d,k,m,r,u,x){a.$d(this.Zd);I(k,V);I(m,Ba);this._drawImageRectOptions(d,V,Ba,r,u,x||null)};a.Canvas.prototype.drawLine=function(d,k,m,r,u){a.$d(this.Zd);this._drawLine(d,k,m,r,u)};a.Canvas.prototype.drawOval=function(d,k){a.$d(this.Zd);d=I(d);this._drawOval(d,k)};a.Canvas.prototype.drawPaint=function(d){a.$d(this.Zd);this._drawPaint(d)};a.Canvas.prototype.drawParagraph=function(d,k,m){a.$d(this.Zd);this._drawParagraph(d,k,m)};a.Canvas.prototype.drawPatch=function(d,k,m,r,u){if(24>d.length)throw"Need 12 cubic points";
if(k&&4>k.length)throw"Need 4 colors";if(m&&8>m.length)throw"Need 4 shader coordinates";a.$d(this.Zd);const x=l(d,"HEAPF32"),B=k?l(c(k),"HEAPU32"):K,F=m?l(m,"HEAPF32"):K;r||(r=a.BlendMode.Modulate);this._drawPatch(x,B,F,r,u);h(F,m);h(B,k);h(x,d)};a.Canvas.prototype.drawPath=function(d,k){a.$d(this.Zd);this._drawPath(d,k)};a.Canvas.prototype.drawPicture=function(d){a.$d(this.Zd);this._drawPicture(d)};a.Canvas.prototype.drawPoints=function(d,k,m){a.$d(this.Zd);var r=l(k,"HEAPF32");this._drawPoints(d,
r,k.length/2,m);h(r,k)};a.Canvas.prototype.drawRRect=function(d,k){a.$d(this.Zd);d=R(d);this._drawRRect(d,k)};a.Canvas.prototype.drawRect=function(d,k){a.$d(this.Zd);d=I(d);this._drawRect(d,k)};a.Canvas.prototype.drawRect4f=function(d,k,m,r,u){a.$d(this.Zd);this._drawRect4f(d,k,m,r,u)};a.Canvas.prototype.drawShadow=function(d,k,m,r,u,x,B){a.$d(this.Zd);var F=l(u,"HEAPF32"),E=l(x,"HEAPF32");k=l(k,"HEAPF32",vb);m=l(m,"HEAPF32",wb);this._drawShadow(d,k,m,r,F,E,B);h(F,u);h(E,x)};a.getShadowLocalBounds=
function(d,k,m,r,u,x,B){d=t(d);m=l(m,"HEAPF32",vb);r=l(r,"HEAPF32",wb);if(!this._getShadowLocalBounds(d,k,m,r,u,x,V))return null;k=ca.toTypedArray();return B?(B.set(k),B):k.slice()};a.Canvas.prototype.drawTextBlob=function(d,k,m,r){a.$d(this.Zd);this._drawTextBlob(d,k,m,r)};a.Canvas.prototype.drawVertices=function(d,k,m){a.$d(this.Zd);this._drawVertices(d,k,m)};a.Canvas.prototype.getDeviceClipBounds=function(d){this._getDeviceClipBounds(Na);var k=ab.toTypedArray();d?d.set(k):d=k.slice();return d};
a.Canvas.prototype.quickReject=function(d){d=I(d);return this._quickReject(d)};a.Canvas.prototype.getLocalToDevice=function(){this._getLocalToDevice(ma);for(var d=ma,k=Array(16),m=0;16>m;m++)k[m]=a.HEAPF32[d/4+m];return k};a.Canvas.prototype.getTotalMatrix=function(){this._getTotalMatrix(Q);for(var d=Array(9),k=0;9>k;k++)d[k]=a.HEAPF32[Q/4+k];return d};a.Canvas.prototype.makeSurface=function(d){d=this._makeSurface(d);d.Zd=this.Zd;return d};a.Canvas.prototype.readPixels=function(d,k,m,r,u){a.$d(this.Zd);
return g(this,d,k,m,r,u)};a.Canvas.prototype.saveLayer=function(d,k,m,r,u){k=I(k);return this._saveLayer(d||null,k,m||null,r||0,u||a.TileMode.Clamp)};a.Canvas.prototype.writePixels=function(d,k,m,r,u,x,B,F){if(d.byteLength%(k*m))throw"pixels length must be a multiple of the srcWidth * srcHeight";a.$d(this.Zd);var E=d.byteLength/(k*m);x=x||a.AlphaType.Unpremul;B=B||a.ColorType.RGBA_8888;F=F||a.ColorSpace.SRGB;var T=E*k;E=l(d,"HEAPU8");k=this._writePixels({width:k,height:m,colorType:B,alphaType:x,colorSpace:F},
E,T,r,u);h(E,d);return k};a.ColorFilter.MakeBlend=function(d,k,m){d=y(d);m=m||a.ColorSpace.SRGB;return a.ColorFilter._MakeBlend(d,k,m)};a.ColorFilter.MakeMatrix=function(d){if(!d||20!==d.length)throw"invalid color matrix";var k=l(d,"HEAPF32"),m=a.ColorFilter._makeMatrix(k);h(k,d);return m};a.ContourMeasure.prototype.getPosTan=function(d,k){this._getPosTan(d,V);d=ca.toTypedArray();return k?(k.set(d),k):d.slice()};a.ImageFilter.prototype.getOutputBounds=function(d,k,m){d=I(d,V);k=t(k);this._getOutputBounds(d,
k,Na);k=ab.toTypedArray();return m?(m.set(k),m):k.slice()};a.ImageFilter.MakeDropShadow=function(d,k,m,r,u,x){u=y(u,ia);return a.ImageFilter._MakeDropShadow(d,k,m,r,u,x)};a.ImageFilter.MakeDropShadowOnly=function(d,k,m,r,u,x){u=y(u,ia);return a.ImageFilter._MakeDropShadowOnly(d,k,m,r,u,x)};a.ImageFilter.MakeImage=function(d,k,m,r){m=I(m,V);r=I(r,Ba);if("B"in k&&"C"in k)return a.ImageFilter._MakeImageCubic(d,k.B,k.C,m,r);const u=k.filter;let x=a.MipmapMode.None;"mipmap"in k&&(x=k.mipmap);return a.ImageFilter._MakeImageOptions(d,
u,x,m,r)};a.ImageFilter.MakeMatrixTransform=function(d,k,m){d=t(d);if("B"in k&&"C"in k)return a.ImageFilter._MakeMatrixTransformCubic(d,k.B,k.C,m);const r=k.filter;let u=a.MipmapMode.None;"mipmap"in k&&(u=k.mipmap);return a.ImageFilter._MakeMatrixTransformOptions(d,r,u,m)};a.Paint.prototype.getColor=function(){this._getColor(ia);return H(ia)};a.Paint.prototype.setColor=function(d,k){k=k||null;d=y(d);this._setColor(d,k)};a.Paint.prototype.setColorComponents=function(d,k,m,r,u){u=u||null;d=C(d,k,m,
r);this._setColor(d,u)};a.Path.prototype.getPoint=function(d,k){this._getPoint(d,V);d=ca.toTypedArray();return k?(k[0]=d[0],k[1]=d[1],k):d.slice(0,2)};a.Picture.prototype.makeShader=function(d,k,m,r,u){r=t(r);u=I(u);return this._makeShader(d,k,m,r,u)};a.Picture.prototype.cullRect=function(d){this._cullRect(V);var k=ca.toTypedArray();return d?(d.set(k),d):k.slice()};a.PictureRecorder.prototype.beginRecording=function(d,k){d=I(d);return this._beginRecording(d,!!k)};a.Surface.prototype.getCanvas=function(){var d=
this._getCanvas();d.Zd=this.Zd;return d};a.Surface.prototype.makeImageSnapshot=function(d){a.$d(this.Zd);d=l(d,"HEAP32",Na);return this._makeImageSnapshot(d)};a.Surface.prototype.makeSurface=function(d){a.$d(this.Zd);d=this._makeSurface(d);d.Zd=this.Zd;return d};a.Surface.prototype.af=function(d,k){this.te||(this.te=this.getCanvas());return requestAnimationFrame(function(){a.$d(this.Zd);d(this.te);this.flush(k)}.bind(this))};a.Surface.prototype.requestAnimationFrame||(a.Surface.prototype.requestAnimationFrame=
a.Surface.prototype.af);a.Surface.prototype.Ye=function(d,k){this.te||(this.te=this.getCanvas());requestAnimationFrame(function(){a.$d(this.Zd);d(this.te);this.flush(k);this.dispose()}.bind(this))};a.Surface.prototype.drawOnce||(a.Surface.prototype.drawOnce=a.Surface.prototype.Ye);a.PathEffect.MakeDash=function(d,k){k||=0;if(!d.length||1===d.length%2)throw"Intervals array must have even length";var m=l(d,"HEAPF32");k=a.PathEffect._MakeDash(m,d.length,k);h(m,d);return k};a.PathEffect.MakeLine2D=function(d,
k){k=t(k);return a.PathEffect._MakeLine2D(d,k)};a.PathEffect.MakePath2D=function(d,k){d=t(d);return a.PathEffect._MakePath2D(d,k)};a.Shader.MakeColor=function(d,k){k=k||null;d=y(d);return a.Shader._MakeColor(d,k)};a.Shader.Blend=a.Shader.MakeBlend;a.Shader.Color=a.Shader.MakeColor;a.Shader.MakeLinearGradient=function(d,k,m,r,u,x,B,F){F=F||null;var E=p(m),T=l(r,"HEAPF32");B=B||0;x=t(x);var U=ca.toTypedArray();U.set(d);U.set(k,2);d=a.Shader._MakeLinearGradient(V,E.he,E.colorType,T,E.count,u,B,x,F);
h(E.he,m);r&&h(T,r);return d};a.Shader.MakeRadialGradient=function(d,k,m,r,u,x,B,F){F=F||null;var E=p(m),T=l(r,"HEAPF32");B=B||0;x=t(x);d=a.Shader._MakeRadialGradient(d[0],d[1],k,E.he,E.colorType,T,E.count,u,B,x,F);h(E.he,m);r&&h(T,r);return d};a.Shader.MakeSweepGradient=function(d,k,m,r,u,x,B,F,E,T){T=T||null;var U=p(m),n=l(r,"HEAPF32");B=B||0;F=F||0;E=E||360;x=t(x);d=a.Shader._MakeSweepGradient(d,k,U.he,U.colorType,n,U.count,u,F,E,B,x,T);h(U.he,m);r&&h(n,r);return d};a.Shader.MakeTwoPointConicalGradient=
function(d,k,m,r,u,x,B,F,E,T){T=T||null;var U=p(u),n=l(x,"HEAPF32");E=E||0;F=t(F);var w=ca.toTypedArray();w.set(d);w.set(m,2);d=a.Shader._MakeTwoPointConicalGradient(V,k,r,U.he,U.colorType,n,U.count,B,E,F,T);h(U.he,u);x&&h(n,x);return d};a.Vertices.prototype.bounds=function(d){this._bounds(V);var k=ca.toTypedArray();return d?(d.set(k),d):k.slice()};a.ce&&a.ce.forEach(function(d){d()})};a.computeTonalColors=function(g){var d=l(g.ambient,"HEAPF32"),k=l(g.spot,"HEAPF32");this._computeTonalColors(d,k);
var m={ambient:H(d),spot:H(k)};h(d,g.ambient);h(k,g.spot);return m};a.LTRBRect=function(g,d,k,m){return Float32Array.of(g,d,k,m)};a.XYWHRect=function(g,d,k,m){return Float32Array.of(g,d,g+k,d+m)};a.LTRBiRect=function(g,d,k,m){return Int32Array.of(g,d,k,m)};a.XYWHiRect=function(g,d,k,m){return Int32Array.of(g,d,g+k,d+m)};a.RRectXY=function(g,d,k){return Float32Array.of(g[0],g[1],g[2],g[3],d,k,d,k,d,k,d,k)};a.MakeAnimatedImageFromEncoded=function(g){g=new Uint8Array(g);var d=a._malloc(g.byteLength);
a.HEAPU8.set(g,d);return(g=a._decodeAnimatedImage(d,g.byteLength))?g:null};a.MakeImageFromEncoded=function(g){g=new Uint8Array(g);var d=a._malloc(g.byteLength);a.HEAPU8.set(g,d);return(g=a._decodeImage(d,g.byteLength))?g:null};var bb=null;a.MakeImageFromCanvasImageSource=function(g){var d=a.Ce(g),k=a.Be(g);bb||=document.createElement("canvas");bb.width=d;bb.height=k;var m=bb.getContext("2d",{willReadFrequently:!0});m.drawImage(g,0,0);g=m.getImageData(0,0,d,k);return a.MakeImage({width:d,height:k,
alphaType:a.AlphaType.Unpremul,colorType:a.ColorType.RGBA_8888,colorSpace:a.ColorSpace.SRGB},g.data,4*d)};a.MakeImage=function(g,d,k){var m=a._malloc(d.length);a.HEAPU8.set(d,m);return a._MakeImage(g,m,d.length,k)};a.MakeVertices=function(g,d,k,m,r,u){var x=r&&r.length||0,B=0;k&&k.length&&(B|=1);m&&m.length&&(B|=2);void 0===u||u||(B|=4);g=new a._VerticesBuilder(g,d.length/2,x,B);l(d,"HEAPF32",g.positions());g.texCoords()&&l(k,"HEAPF32",g.texCoords());g.colors()&&l(c(m),"HEAPU32",g.colors());g.indices()&&
l(r,"HEAPU16",g.indices());return g.detach()};(function(g){g.ce=g.ce||[];g.ce.push(function(){function d(n){n&&(n.dir=0===n.dir?g.TextDirection.RTL:g.TextDirection.LTR);return n}function k(n){if(!n||!n.length)return[];for(var w=[],N=0;N<n.length;N+=5){var X=g.LTRBRect(n[N],n[N+1],n[N+2],n[N+3]),xa=g.TextDirection.LTR;0===n[N+4]&&(xa=g.TextDirection.RTL);w.push({rect:X,dir:xa})}g._free(n.byteOffset);return w}function m(n){n=n||{};void 0===n.weight&&(n.weight=g.FontWeight.Normal);n.width=n.width||g.FontWidth.Normal;
n.slant=n.slant||g.FontSlant.Upright;return n}function r(n){if(!n||!n.length)return K;for(var w=[],N=0;N<n.length;N++){var X=u(n[N]);w.push(X)}return l(w,"HEAPU32")}function u(n){if(F[n])return F[n];var w=qa(n)+1,N=g._malloc(w);ra(n,N,w);return F[n]=N}function x(n){n._colorPtr=y(n.color);n._foregroundColorPtr=K;n._backgroundColorPtr=K;n._decorationColorPtr=K;n.foregroundColor&&(n._foregroundColorPtr=y(n.foregroundColor,E));n.backgroundColor&&(n._backgroundColorPtr=y(n.backgroundColor,T));n.decorationColor&&
(n._decorationColorPtr=y(n.decorationColor,U));Array.isArray(n.fontFamilies)&&n.fontFamilies.length?(n._fontFamiliesPtr=r(n.fontFamilies),n._fontFamiliesLen=n.fontFamilies.length):(n._fontFamiliesPtr=K,n._fontFamiliesLen=0);if(n.locale){var w=n.locale;n._localePtr=u(w);n._localeLen=qa(w)}else n._localePtr=K,n._localeLen=0;if(Array.isArray(n.shadows)&&n.shadows.length){w=n.shadows;var N=w.map(function(na){return na.color||g.BLACK}),X=w.map(function(na){return na.blurRadius||0});n._shadowLen=w.length;
for(var xa=g._malloc(8*w.length),xb=xa/4,yb=0;yb<w.length;yb++){var ac=w[yb].offset||[0,0];g.HEAPF32[xb]=ac[0];g.HEAPF32[xb+1]=ac[1];xb+=2}n._shadowColorsPtr=p(N).he;n._shadowOffsetsPtr=xa;n._shadowBlurRadiiPtr=l(X,"HEAPF32")}else n._shadowLen=0,n._shadowColorsPtr=K,n._shadowOffsetsPtr=K,n._shadowBlurRadiiPtr=K;Array.isArray(n.fontFeatures)&&n.fontFeatures.length?(w=n.fontFeatures,N=w.map(function(na){return na.name}),X=w.map(function(na){return na.value}),n._fontFeatureLen=w.length,n._fontFeatureNamesPtr=
r(N),n._fontFeatureValuesPtr=l(X,"HEAPU32")):(n._fontFeatureLen=0,n._fontFeatureNamesPtr=K,n._fontFeatureValuesPtr=K);Array.isArray(n.fontVariations)&&n.fontVariations.length?(w=n.fontVariations,N=w.map(function(na){return na.axis}),X=w.map(function(na){return na.value}),n._fontVariationLen=w.length,n._fontVariationAxesPtr=r(N),n._fontVariationValuesPtr=l(X,"HEAPF32")):(n._fontVariationLen=0,n._fontVariationAxesPtr=K,n._fontVariationValuesPtr=K)}function B(n){g._free(n._fontFamiliesPtr);g._free(n._shadowColorsPtr);
g._free(n._shadowOffsetsPtr);g._free(n._shadowBlurRadiiPtr);g._free(n._fontFeatureNamesPtr);g._free(n._fontFeatureValuesPtr);g._free(n._fontVariationAxesPtr);g._free(n._fontVariationValuesPtr)}g.Paragraph.prototype.getRectsForRange=function(n,w,N,X){n=this._getRectsForRange(n,w,N,X);return k(n)};g.Paragraph.prototype.getRectsForPlaceholders=function(){var n=this._getRectsForPlaceholders();return k(n)};g.Paragraph.prototype.getGlyphInfoAt=function(n){return d(this._getGlyphInfoAt(n))};g.Paragraph.prototype.getClosestGlyphInfoAtCoordinate=
function(n,w){return d(this._getClosestGlyphInfoAtCoordinate(n,w))};g.TypefaceFontProvider.prototype.registerFont=function(n,w){n=g.Typeface.MakeTypefaceFromData(n);if(!n)return null;w=u(w);this._registerFont(n,w);n.delete()};g.ParagraphStyle=function(n){n.disableHinting=n.disableHinting||!1;if(n.ellipsis){var w=n.ellipsis;n._ellipsisPtr=u(w);n._ellipsisLen=qa(w)}else n._ellipsisPtr=K,n._ellipsisLen=0;null==n.heightMultiplier&&(n.heightMultiplier=-1);n.maxLines=n.maxLines||0;n.replaceTabCharacters=
n.replaceTabCharacters||!1;w=(w=n.strutStyle)||{};w.strutEnabled=w.strutEnabled||!1;w.strutEnabled&&Array.isArray(w.fontFamilies)&&w.fontFamilies.length?(w._fontFamiliesPtr=r(w.fontFamilies),w._fontFamiliesLen=w.fontFamilies.length):(w._fontFamiliesPtr=K,w._fontFamiliesLen=0);w.fontStyle=m(w.fontStyle);null==w.fontSize&&(w.fontSize=-1);null==w.heightMultiplier&&(w.heightMultiplier=-1);w.halfLeading=w.halfLeading||!1;w.leading=w.leading||0;w.forceStrutHeight=w.forceStrutHeight||!1;n.strutStyle=w;n.textAlign=
n.textAlign||g.TextAlign.Start;n.textDirection=n.textDirection||g.TextDirection.LTR;n.textHeightBehavior=n.textHeightBehavior||g.TextHeightBehavior.All;n.textStyle=g.TextStyle(n.textStyle);n.applyRoundingHack=!1!==n.applyRoundingHack;return n};g.TextStyle=function(n){n.color||(n.color=g.BLACK);n.decoration=n.decoration||0;n.decorationThickness=n.decorationThickness||0;n.decorationStyle=n.decorationStyle||g.DecorationStyle.Solid;n.textBaseline=n.textBaseline||g.TextBaseline.Alphabetic;null==n.fontSize&&
(n.fontSize=-1);n.letterSpacing=n.letterSpacing||0;n.wordSpacing=n.wordSpacing||0;null==n.heightMultiplier&&(n.heightMultiplier=-1);n.halfLeading=n.halfLeading||!1;n.fontStyle=m(n.fontStyle);return n};var F={},E=g._malloc(16),T=g._malloc(16),U=g._malloc(16);g.ParagraphBuilder.Make=function(n,w){x(n.textStyle);w=g.ParagraphBuilder._Make(n,w);B(n.textStyle);return w};g.ParagraphBuilder.MakeFromFontProvider=function(n,w){x(n.textStyle);w=g.ParagraphBuilder._MakeFromFontProvider(n,w);B(n.textStyle);return w};
g.ParagraphBuilder.MakeFromFontCollection=function(n,w){x(n.textStyle);w=g.ParagraphBuilder._MakeFromFontCollection(n,w);B(n.textStyle);return w};g.ParagraphBuilder.ShapeText=function(n,w,N){let X=0;for(const xa of w)X+=xa.length;if(X!==n.length)throw"Accumulated block lengths must equal text.length";return g.ParagraphBuilder._ShapeText(n,w,N)};g.ParagraphBuilder.prototype.pushStyle=function(n){x(n);this._pushStyle(n);B(n)};g.ParagraphBuilder.prototype.pushPaintStyle=function(n,w,N){x(n);this._pushPaintStyle(n,
w,N);B(n)};g.ParagraphBuilder.prototype.addPlaceholder=function(n,w,N,X,xa){N=N||g.PlaceholderAlignment.Baseline;X=X||g.TextBaseline.Alphabetic;this._addPlaceholder(n||0,w||0,N,X,xa||0)};g.ParagraphBuilder.prototype.setWordsUtf8=function(n){var w=l(n,"HEAPU32");this._setWordsUtf8(w,n&&n.length||0);h(w,n)};g.ParagraphBuilder.prototype.setWordsUtf16=function(n){var w=l(n,"HEAPU32");this._setWordsUtf16(w,n&&n.length||0);h(w,n)};g.ParagraphBuilder.prototype.setGraphemeBreaksUtf8=function(n){var w=l(n,
"HEAPU32");this._setGraphemeBreaksUtf8(w,n&&n.length||0);h(w,n)};g.ParagraphBuilder.prototype.setGraphemeBreaksUtf16=function(n){var w=l(n,"HEAPU32");this._setGraphemeBreaksUtf16(w,n&&n.length||0);h(w,n)};g.ParagraphBuilder.prototype.setLineBreaksUtf8=function(n){var w=l(n,"HEAPU32");this._setLineBreaksUtf8(w,n&&n.length||0);h(w,n)};g.ParagraphBuilder.prototype.setLineBreaksUtf16=function(n){var w=l(n,"HEAPU32");this._setLineBreaksUtf16(w,n&&n.length||0);h(w,n)}})})(q);a.ce=a.ce||[];a.ce.push(function(){});
a.ce=a.ce||[];a.ce.push(function(){a.Canvas.prototype.drawText=function(g,d,k,m,r){var u=qa(g),x=a._malloc(u+1);ra(g,x,u+1);this._drawSimpleText(x,u,d,k,r,m);a._free(x)};a.Canvas.prototype.drawGlyphs=function(g,d,k,m,r,u){if(!(2*g.length<=d.length))throw"Not enough positions for the array of gyphs";a.$d(this.Zd);const x=l(g,"HEAPU16"),B=l(d,"HEAPF32");this._drawGlyphs(g.length,x,B,k,m,r,u);h(B,d);h(x,g)};a.Font.prototype.getGlyphBounds=function(g,d,k){var m=l(g,"HEAPU16"),r=a._malloc(16*g.length);
this._getGlyphWidthBounds(m,g.length,K,r,d||null);d=new Float32Array(a.HEAPU8.buffer,r,4*g.length);h(m,g);if(k)return k.set(d),a._free(r),k;g=Float32Array.from(d);a._free(r);return g};a.Font.prototype.getGlyphIDs=function(g,d,k){d||(d=g.length);var m=qa(g)+1,r=a._malloc(m);ra(g,r,m);g=a._malloc(2*d);d=this._getGlyphIDs(r,m-1,d,g);a._free(r);if(0>d)return a._free(g),null;r=new Uint16Array(a.HEAPU8.buffer,g,d);if(k)return k.set(r),a._free(g),k;k=Uint16Array.from(r);a._free(g);return k};a.Font.prototype.getGlyphIntercepts=
function(g,d,k,m){var r=l(g,"HEAPU16"),u=l(d,"HEAPF32");return this._getGlyphIntercepts(r,g.length,!(g&&g._ck),u,d.length,!(d&&d._ck),k,m)};a.Font.prototype.getGlyphWidths=function(g,d,k){var m=l(g,"HEAPU16"),r=a._malloc(4*g.length);this._getGlyphWidthBounds(m,g.length,r,K,d||null);d=new Float32Array(a.HEAPU8.buffer,r,g.length);h(m,g);if(k)return k.set(d),a._free(r),k;g=Float32Array.from(d);a._free(r);return g};a.FontMgr.FromData=function(){if(!arguments.length)return null;var g=arguments;1===g.length&&
Array.isArray(g[0])&&(g=arguments[0]);if(!g.length)return null;for(var d=[],k=[],m=0;m<g.length;m++){var r=new Uint8Array(g[m]),u=l(r,"HEAPU8");d.push(u);k.push(r.byteLength)}d=l(d,"HEAPU32");k=l(k,"HEAPU32");g=a.FontMgr._fromData(d,k,g.length);a._free(d);a._free(k);return g};a.Typeface.MakeTypefaceFromData=function(g){g=new Uint8Array(g);var d=l(g,"HEAPU8");return(g=a.Typeface._MakeTypefaceFromData(d,g.byteLength))?g:null};a.Typeface.MakeFreeTypeFaceFromData=a.Typeface.MakeTypefaceFromData;a.Typeface.prototype.getGlyphIDs=
function(g,d,k){d||(d=g.length);var m=qa(g)+1,r=a._malloc(m);ra(g,r,m);g=a._malloc(2*d);d=this._getGlyphIDs(r,m-1,d,g);a._free(r);if(0>d)return a._free(g),null;r=new Uint16Array(a.HEAPU8.buffer,g,d);if(k)return k.set(r),a._free(g),k;k=Uint16Array.from(r);a._free(g);return k};a.TextBlob.MakeOnPath=function(g,d,k,m){if(g&&g.length&&d&&d.countPoints()){if(1===d.countPoints())return this.MakeFromText(g,k);m||=0;var r=k.getGlyphIDs(g);r=k.getGlyphWidths(r);var u=[];d=new a.ContourMeasureIter(d,!1,1);for(var x=
d.next(),B=new Float32Array(4),F=0;F<g.length&&x;F++){var E=r[F];m+=E/2;if(m>x.length()){x.delete();x=d.next();if(!x){g=g.substring(0,F);break}m=E/2}x.getPosTan(m,B);var T=B[2],U=B[3];u.push(T,U,B[0]-E/2*T,B[1]-E/2*U);m+=E/2}g=this.MakeFromRSXform(g,u,k);x&&x.delete();d.delete();return g}};a.TextBlob.MakeFromRSXform=function(g,d,k){var m=qa(g)+1,r=a._malloc(m);ra(g,r,m);g=l(d,"HEAPF32");k=a.TextBlob._MakeFromRSXform(r,m-1,g,k);a._free(r);return k?k:null};a.TextBlob.MakeFromRSXformGlyphs=function(g,
d,k){var m=l(g,"HEAPU16");d=l(d,"HEAPF32");k=a.TextBlob._MakeFromRSXformGlyphs(m,2*g.length,d,k);h(m,g);return k?k:null};a.TextBlob.MakeFromGlyphs=function(g,d){var k=l(g,"HEAPU16");d=a.TextBlob._MakeFromGlyphs(k,2*g.length,d);h(k,g);return d?d:null};a.TextBlob.MakeFromText=function(g,d){var k=qa(g)+1,m=a._malloc(k);ra(g,m,k);g=a.TextBlob._MakeFromText(m,k-1,d);a._free(m);return g?g:null};a.MallocGlyphIDs=function(g){return a.Malloc(Uint16Array,g)}});a.ce=a.ce||[];a.ce.push(function(){a.MakePicture=
function(g){g=new Uint8Array(g);var d=a._malloc(g.byteLength);a.HEAPU8.set(g,d);return(g=a._MakePicture(d,g.byteLength))?g:null}});a.ce=a.ce||[];a.ce.push(function(){a.RuntimeEffect.Make=function(g,d){return a.RuntimeEffect._Make(g,{onError:d||function(k){console.log("RuntimeEffect error",k)}})};a.RuntimeEffect.MakeForBlender=function(g,d){return a.RuntimeEffect._MakeForBlender(g,{onError:d||function(k){console.log("RuntimeEffect error",k)}})};a.RuntimeEffect.prototype.makeShader=function(g,d){var k=
!g._ck,m=l(g,"HEAPF32");d=t(d);return this._makeShader(m,4*g.length,k,d)};a.RuntimeEffect.prototype.makeShaderWithChildren=function(g,d,k){var m=!g._ck,r=l(g,"HEAPF32");k=t(k);for(var u=[],x=0;x<d.length;x++)u.push(d[x].Yd.ae);d=l(u,"HEAPU32");return this._makeShaderWithChildren(r,4*g.length,m,d,u.length,k)};a.RuntimeEffect.prototype.makeBlender=function(g){var d=!g._ck,k=l(g,"HEAPF32");return this._makeBlender(k,4*g.length,d)}})})(q);var sa=Object.assign({},q),ta="",ua,va;
if(fa||ha)ha?ta=self.location.href:"undefined"!=typeof document&&document.currentScript&&(ta=document.currentScript.src),_scriptName&&(ta=_scriptName),ta.startsWith("blob:")?ta="":ta=ta.substr(0,ta.replace(/[?#].*/,"").lastIndexOf("/")+1),ha&&(va=a=>{var b=new XMLHttpRequest;b.open("GET",a,!1);b.responseType="arraybuffer";b.send(null);return new Uint8Array(b.response)}),ua=a=>fetch(a,{credentials:"same-origin"}).then(b=>b.ok?b.arrayBuffer():Promise.reject(Error(b.status+" : "+b.url)));
var wa=console.log.bind(console),ya=console.error.bind(console);Object.assign(q,sa);sa=null;var za,Aa=!1,Ca,A,Da,Ea,D,G,J,Ga;function Ha(){var a=za.buffer;q.HEAP8=Ca=new Int8Array(a);q.HEAP16=Da=new Int16Array(a);q.HEAPU8=A=new Uint8Array(a);q.HEAPU16=Ea=new Uint16Array(a);q.HEAP32=D=new Int32Array(a);q.HEAPU32=G=new Uint32Array(a);q.HEAPF32=J=new Float32Array(a);q.HEAPF64=Ga=new Float64Array(a)}var Ia=[],Ja=[],Ka=[],La=0,Ma=null,Oa=null;
function Pa(a){a="Aborted("+a+")";ya(a);Aa=!0;a=new WebAssembly.RuntimeError(a+". Build with -sASSERTIONS for more info.");da(a);throw a;}var Qa=a=>a.startsWith("data:application/octet-stream;base64,"),Ra;function Sa(a){return ua(a).then(b=>new Uint8Array(b),()=>{if(va)var b=va(a);else throw"both async and sync fetching of the wasm failed";return b})}function Ta(a,b,c){return Sa(a).then(e=>WebAssembly.instantiate(e,b)).then(c,e=>{ya(`failed to asynchronously prepare wasm: ${e}`);Pa(e)})}
function Ua(a,b){var c=Ra;return"function"!=typeof WebAssembly.instantiateStreaming||Qa(c)||"function"!=typeof fetch?Ta(c,a,b):fetch(c,{credentials:"same-origin"}).then(e=>WebAssembly.instantiateStreaming(e,a).then(b,function(f){ya(`wasm streaming compile failed: ${f}`);ya("falling back to ArrayBuffer instantiation");return Ta(c,a,b)}))}function Va(a){this.name="ExitStatus";this.message=`Program terminated with exit(${a})`;this.status=a}var Wa=a=>{a.forEach(b=>b(q))},Xa=q.noExitRuntime||!0;
class Ya{constructor(a){this.ae=a-24}}
var Za=0,$a=0,cb="undefined"!=typeof TextDecoder?new TextDecoder:void 0,db=(a,b=0,c=NaN)=>{var e=b+c;for(c=b;a[c]&&!(c>=e);)++c;if(16<c-b&&a.buffer&&cb)return cb.decode(a.subarray(b,c));for(e="";b<c;){var f=a[b++];if(f&128){var h=a[b++]&63;if(192==(f&224))e+=String.fromCharCode((f&31)<<6|h);else{var l=a[b++]&63;f=224==(f&240)?(f&15)<<12|h<<6|l:(f&7)<<18|h<<12|l<<6|a[b++]&63;65536>f?e+=String.fromCharCode(f):(f-=65536,e+=String.fromCharCode(55296|f>>10,56320|f&1023))}}else e+=String.fromCharCode(f)}return e},
eb={},fb=a=>{for(;a.length;){var b=a.pop();a.pop()(b)}};function gb(a){return this.fromWireType(G[a>>2])}
var hb={},ib={},jb={},kb,mb=(a,b,c)=>{function e(p){p=c(p);if(p.length!==a.length)throw new kb("Mismatched type converter count");for(var t=0;t<a.length;++t)lb(a[t],p[t])}a.forEach(p=>jb[p]=b);var f=Array(b.length),h=[],l=0;b.forEach((p,t)=>{ib.hasOwnProperty(p)?f[t]=ib[p]:(h.push(p),hb.hasOwnProperty(p)||(hb[p]=[]),hb[p].push(()=>{f[t]=ib[p];++l;l===h.length&&e(f)}))});0===h.length&&e(f)},nb,L=a=>{for(var b="";A[a];)b+=nb[A[a++]];return b},M;
function ob(a,b,c={}){var e=b.name;if(!a)throw new M(`type "${e}" must have a positive integer typeid pointer`);if(ib.hasOwnProperty(a)){if(c.nf)return;throw new M(`Cannot register type '${e}' twice`);}ib[a]=b;delete jb[a];hb.hasOwnProperty(a)&&(b=hb[a],delete hb[a],b.forEach(f=>f()))}function lb(a,b,c={}){return ob(a,b,c)}
var pb=a=>{throw new M(a.Yd.de.be.name+" instance already deleted");},qb=!1,rb=()=>{},sb=(a,b,c)=>{if(b===c)return a;if(void 0===c.ge)return null;a=sb(a,b,c.ge);return null===a?null:c.ef(a)},tb={},zb={},Ab=(a,b)=>{if(void 0===b)throw new M("ptr should not be undefined");for(;a.ge;)b=a.ye(b),a=a.ge;return zb[b]},Cb=(a,b)=>{if(!b.de||!b.ae)throw new kb("makeClassHandle requires ptr and ptrType");if(!!b.ie!==!!b.ee)throw new kb("Both smartPtrType and smartPtr must be specified");b.count={value:1};return Bb(Object.create(a,
{Yd:{value:b,writable:!0}}))},Bb=a=>{if("undefined"===typeof FinalizationRegistry)return Bb=b=>b,a;qb=new FinalizationRegistry(b=>{b=b.Yd;--b.count.value;0===b.count.value&&(b.ee?b.ie.ne(b.ee):b.de.be.ne(b.ae))});Bb=b=>{var c=b.Yd;c.ee&&qb.register(b,{Yd:c},b);return b};rb=b=>{qb.unregister(b)};return Bb(a)},Db=[];function Eb(){}
var Fb=(a,b)=>Object.defineProperty(b,"name",{value:a}),Gb=(a,b,c)=>{if(void 0===a[b].fe){var e=a[b];a[b]=function(...f){if(!a[b].fe.hasOwnProperty(f.length))throw new M(`Function '${c}' called with an invalid number of arguments (${f.length}) - expects one of (${a[b].fe})!`);return a[b].fe[f.length].apply(this,f)};a[b].fe=[];a[b].fe[e.oe]=e}},Hb=(a,b,c)=>{if(q.hasOwnProperty(a)){if(void 0===c||void 0!==q[a].fe&&void 0!==q[a].fe[c])throw new M(`Cannot register public name '${a}' twice`);Gb(q,a,a);
if(q[a].fe.hasOwnProperty(c))throw new M(`Cannot register multiple overloads of a function with the same number of arguments (${c})!`);q[a].fe[c]=b}else q[a]=b,q[a].oe=c},Ib=a=>{a=a.replace(/[^a-zA-Z0-9_]/g,"$");var b=a.charCodeAt(0);return 48<=b&&57>=b?`_${a}`:a};function Jb(a,b,c,e,f,h,l,p){this.name=a;this.constructor=b;this.se=c;this.ne=e;this.ge=f;this.hf=h;this.ye=l;this.ef=p;this.rf=[]}
var Kb=(a,b,c)=>{for(;b!==c;){if(!b.ye)throw new M(`Expected null or instance of ${c.name}, got an instance of ${b.name}`);a=b.ye(a);b=b.ge}return a};function Lb(a,b){if(null===b){if(this.Me)throw new M(`null is not a valid ${this.name}`);return 0}if(!b.Yd)throw new M(`Cannot pass "${Mb(b)}" as a ${this.name}`);if(!b.Yd.ae)throw new M(`Cannot pass deleted object as a pointer of type ${this.name}`);return Kb(b.Yd.ae,b.Yd.de.be,this.be)}
function Nb(a,b){if(null===b){if(this.Me)throw new M(`null is not a valid ${this.name}`);if(this.Fe){var c=this.Ne();null!==a&&a.push(this.ne,c);return c}return 0}if(!b||!b.Yd)throw new M(`Cannot pass "${Mb(b)}" as a ${this.name}`);if(!b.Yd.ae)throw new M(`Cannot pass deleted object as a pointer of type ${this.name}`);if(!this.Ee&&b.Yd.de.Ee)throw new M(`Cannot convert argument of type ${b.Yd.ie?b.Yd.ie.name:b.Yd.de.name} to parameter type ${this.name}`);c=Kb(b.Yd.ae,b.Yd.de.be,this.be);if(this.Fe){if(void 0===
b.Yd.ee)throw new M("Passing raw pointer to smart pointer is illegal");switch(this.wf){case 0:if(b.Yd.ie===this)c=b.Yd.ee;else throw new M(`Cannot convert argument of type ${b.Yd.ie?b.Yd.ie.name:b.Yd.de.name} to parameter type ${this.name}`);break;case 1:c=b.Yd.ee;break;case 2:if(b.Yd.ie===this)c=b.Yd.ee;else{var e=b.clone();c=this.sf(c,Ob(()=>e["delete"]()));null!==a&&a.push(this.ne,c)}break;default:throw new M("Unsupporting sharing policy");}}return c}
function Pb(a,b){if(null===b){if(this.Me)throw new M(`null is not a valid ${this.name}`);return 0}if(!b.Yd)throw new M(`Cannot pass "${Mb(b)}" as a ${this.name}`);if(!b.Yd.ae)throw new M(`Cannot pass deleted object as a pointer of type ${this.name}`);if(b.Yd.de.Ee)throw new M(`Cannot convert argument of type ${b.Yd.de.name} to parameter type ${this.name}`);return Kb(b.Yd.ae,b.Yd.de.be,this.be)}
function Qb(a,b,c,e,f,h,l,p,t,v,y){this.name=a;this.be=b;this.Me=c;this.Ee=e;this.Fe=f;this.qf=h;this.wf=l;this.Ue=p;this.Ne=t;this.sf=v;this.ne=y;f||void 0!==b.ge?this.toWireType=Nb:(this.toWireType=e?Lb:Pb,this.ke=null)}
var Rb=(a,b,c)=>{if(!q.hasOwnProperty(a))throw new kb("Replacing nonexistent public symbol");void 0!==q[a].fe&&void 0!==c?q[a].fe[c]=b:(q[a]=b,q[a].oe=c)},O,Sb=(a,b,c=[])=>{a.includes("j")?(a=a.replace(/p/g,"i"),b=(0,q["dynCall_"+a])(b,...c)):b=O.get(b)(...c);return b},Tb=(a,b)=>(...c)=>Sb(a,b,c),Ub=(a,b)=>{a=L(a);var c=a.includes("j")?Tb(a,b):O.get(b);if("function"!=typeof c)throw new M(`unknown function pointer with signature ${a}: ${b}`);return c},bc,ec=a=>{a=cc(a);var b=L(a);dc(a);return b},fc=
(a,b)=>{function c(h){f[h]||ib[h]||(jb[h]?jb[h].forEach(c):(e.push(h),f[h]=!0))}var e=[],f={};b.forEach(c);throw new bc(`${a}: `+e.map(ec).join([", "]));};function gc(a){for(var b=1;b<a.length;++b)if(null!==a[b]&&void 0===a[b].ke)return!0;return!1}
function hc(a,b,c,e,f){var h=b.length;if(2>h)throw new M("argTypes array size mismatch! Must at least get return value and 'this' types!");var l=null!==b[1]&&null!==c,p=gc(b),t="void"!==b[0].name,v=h-2,y=Array(v),C=[],H=[];return Fb(a,function(...I){H.length=0;C.length=l?2:1;C[0]=f;if(l){var R=b[1].toWireType(H,this);C[1]=R}for(var Q=0;Q<v;++Q)y[Q]=b[Q+2].toWireType(H,I[Q]),C.push(y[Q]);I=e(...C);if(p)fb(H);else for(Q=l?1:2;Q<b.length;Q++){var ba=1===Q?R:y[Q-2];null!==b[Q].ke&&b[Q].ke(ba)}R=t?b[0].fromWireType(I):
void 0;return R})}
var ic=(a,b)=>{for(var c=[],e=0;e<a;e++)c.push(G[b+4*e>>2]);return c},jc=a=>{a=a.trim();const b=a.indexOf("(");return-1!==b?a.substr(0,b):a},kc=[],lc=[],mc=a=>{9<a&&0===--lc[a+1]&&(lc[a]=void 0,kc.push(a))},nc=a=>{if(!a)throw new M("Cannot use deleted val. handle = "+a);return lc[a]},Ob=a=>{switch(a){case void 0:return 2;case null:return 4;case !0:return 6;case !1:return 8;default:const b=kc.pop()||lc.length;lc[b]=a;lc[b+1]=1;return b}},oc={name:"emscripten::val",fromWireType:a=>{var b=nc(a);mc(a);
return b},toWireType:(a,b)=>Ob(b),je:8,readValueFromPointer:gb,ke:null},pc=(a,b,c)=>{switch(b){case 1:return c?function(e){return this.fromWireType(Ca[e])}:function(e){return this.fromWireType(A[e])};case 2:return c?function(e){return this.fromWireType(Da[e>>1])}:function(e){return this.fromWireType(Ea[e>>1])};case 4:return c?function(e){return this.fromWireType(D[e>>2])}:function(e){return this.fromWireType(G[e>>2])};default:throw new TypeError(`invalid integer width (${b}): ${a}`);}},qc=(a,b)=>
{var c=ib[a];if(void 0===c)throw a=`${b} has unknown type ${ec(a)}`,new M(a);return c},Mb=a=>{if(null===a)return"null";var b=typeof a;return"object"===b||"array"===b||"function"===b?a.toString():""+a},rc=(a,b)=>{switch(b){case 4:return function(c){return this.fromWireType(J[c>>2])};case 8:return function(c){return this.fromWireType(Ga[c>>3])};default:throw new TypeError(`invalid float width (${b}): ${a}`);}},sc=(a,b,c)=>{switch(b){case 1:return c?e=>Ca[e]:e=>A[e];case 2:return c?e=>Da[e>>1]:e=>Ea[e>>
1];case 4:return c?e=>D[e>>2]:e=>G[e>>2];default:throw new TypeError(`invalid integer width (${b}): ${a}`);}},ra=(a,b,c)=>{var e=A;if(!(0<c))return 0;var f=b;c=b+c-1;for(var h=0;h<a.length;++h){var l=a.charCodeAt(h);if(55296<=l&&57343>=l){var p=a.charCodeAt(++h);l=65536+((l&1023)<<10)|p&1023}if(127>=l){if(b>=c)break;e[b++]=l}else{if(2047>=l){if(b+1>=c)break;e[b++]=192|l>>6}else{if(65535>=l){if(b+2>=c)break;e[b++]=224|l>>12}else{if(b+3>=c)break;e[b++]=240|l>>18;e[b++]=128|l>>12&63}e[b++]=128|l>>6&
63}e[b++]=128|l&63}}e[b]=0;return b-f},qa=a=>{for(var b=0,c=0;c<a.length;++c){var e=a.charCodeAt(c);127>=e?b++:2047>=e?b+=2:55296<=e&&57343>=e?(b+=4,++c):b+=3}return b},tc="undefined"!=typeof TextDecoder?new TextDecoder("utf-16le"):void 0,uc=(a,b)=>{var c=a>>1;for(var e=c+b/2;!(c>=e)&&Ea[c];)++c;c<<=1;if(32<c-a&&tc)return tc.decode(A.subarray(a,c));c="";for(e=0;!(e>=b/2);++e){var f=Da[a+2*e>>1];if(0==f)break;c+=String.fromCharCode(f)}return c},vc=(a,b,c)=>{c??=2147483647;if(2>c)return 0;c-=2;var e=
b;c=c<2*a.length?c/2:a.length;for(var f=0;f<c;++f)Da[b>>1]=a.charCodeAt(f),b+=2;Da[b>>1]=0;return b-e},wc=a=>2*a.length,xc=(a,b)=>{for(var c=0,e="";!(c>=b/4);){var f=D[a+4*c>>2];if(0==f)break;++c;65536<=f?(f-=65536,e+=String.fromCharCode(55296|f>>10,56320|f&1023)):e+=String.fromCharCode(f)}return e},yc=(a,b,c)=>{c??=2147483647;if(4>c)return 0;var e=b;c=e+c-4;for(var f=0;f<a.length;++f){var h=a.charCodeAt(f);if(55296<=h&&57343>=h){var l=a.charCodeAt(++f);h=65536+((h&1023)<<10)|l&1023}D[b>>2]=h;b+=
4;if(b+4>c)break}D[b>>2]=0;return b-e},zc=a=>{for(var b=0,c=0;c<a.length;++c){var e=a.charCodeAt(c);55296<=e&&57343>=e&&++c;b+=4}return b},Ac=(a,b,c)=>{var e=[];a=a.toWireType(e,c);e.length&&(G[b>>2]=Ob(e));return a},Bc=[],Cc={},Dc=a=>{var b=Cc[a];return void 0===b?L(a):b},Ec=()=>{function a(b){b.$$$embind_global$$$=b;var c="object"==typeof $$$embind_global$$$&&b.$$$embind_global$$$==b;c||delete b.$$$embind_global$$$;return c}if("object"==typeof globalThis)return globalThis;if("object"==typeof $$$embind_global$$$)return $$$embind_global$$$;
"object"==typeof global&&a(global)?$$$embind_global$$$=global:"object"==typeof self&&a(self)&&($$$embind_global$$$=self);if("object"==typeof $$$embind_global$$$)return $$$embind_global$$$;throw Error("unable to get global object.");},Fc=a=>{var b=Bc.length;Bc.push(a);return b},Gc=(a,b)=>{for(var c=Array(a),e=0;e<a;++e)c[e]=qc(G[b+4*e>>2],"parameter "+e);return c},Hc=Reflect.construct,P,Ic=a=>{var b=a.getExtension("ANGLE_instanced_arrays");b&&(a.vertexAttribDivisor=(c,e)=>b.vertexAttribDivisorANGLE(c,
e),a.drawArraysInstanced=(c,e,f,h)=>b.drawArraysInstancedANGLE(c,e,f,h),a.drawElementsInstanced=(c,e,f,h,l)=>b.drawElementsInstancedANGLE(c,e,f,h,l))},Jc=a=>{var b=a.getExtension("OES_vertex_array_object");b&&(a.createVertexArray=()=>b.createVertexArrayOES(),a.deleteVertexArray=c=>b.deleteVertexArrayOES(c),a.bindVertexArray=c=>b.bindVertexArrayOES(c),a.isVertexArray=c=>b.isVertexArrayOES(c))},Kc=a=>{var b=a.getExtension("WEBGL_draw_buffers");b&&(a.drawBuffers=(c,e)=>b.drawBuffersWEBGL(c,e))},Lc=a=>
{var b="ANGLE_instanced_arrays EXT_blend_minmax EXT_disjoint_timer_query EXT_frag_depth EXT_shader_texture_lod EXT_sRGB OES_element_index_uint OES_fbo_render_mipmap OES_standard_derivatives OES_texture_float OES_texture_half_float OES_texture_half_float_linear OES_vertex_array_object WEBGL_color_buffer_float WEBGL_depth_texture WEBGL_draw_buffers EXT_color_buffer_float EXT_conservative_depth EXT_disjoint_timer_query_webgl2 EXT_texture_norm16 NV_shader_noperspective_interpolation WEBGL_clip_cull_distance EXT_clip_control EXT_color_buffer_half_float EXT_depth_clamp EXT_float_blend EXT_polygon_offset_clamp EXT_texture_compression_bptc EXT_texture_compression_rgtc EXT_texture_filter_anisotropic KHR_parallel_shader_compile OES_texture_float_linear WEBGL_blend_func_extended WEBGL_compressed_texture_astc WEBGL_compressed_texture_etc WEBGL_compressed_texture_etc1 WEBGL_compressed_texture_s3tc WEBGL_compressed_texture_s3tc_srgb WEBGL_debug_renderer_info WEBGL_debug_shaders WEBGL_lose_context WEBGL_multi_draw WEBGL_polygon_mode".split(" ");
return(a.getSupportedExtensions()||[]).filter(c=>b.includes(c))},Mc=1,Nc=[],Oc=[],Pc=[],Qc=[],ka=[],Rc=[],Sc=[],pa=[],Tc=[],Uc=[],Vc=[],Xc={},Yc={},Zc=4,$c=0,ja=a=>{for(var b=Mc++,c=a.length;c<b;c++)a[c]=null;return b},ad=(a,b,c,e)=>{for(var f=0;f<a;f++){var h=P[c](),l=h&&ja(e);h?(h.name=l,e[l]=h):S||=1282;D[b+4*f>>2]=l}},la=(a,b)=>{a.Pe||(a.Pe=a.getContext,a.getContext=function(e,f){f=a.Pe(e,f);return"webgl"==e==f instanceof WebGLRenderingContext?f:null});var c=1<b.majorVersion?a.getContext("webgl2",
b):a.getContext("webgl",b);return c?bd(c,b):0},bd=(a,b)=>{var c=ja(pa),e={handle:c,attributes:b,version:b.majorVersion,le:a};a.canvas&&(a.canvas.Xe=e);pa[c]=e;("undefined"==typeof b.ff||b.ff)&&cd(e);return c},oa=a=>{z=pa[a];q.xf=P=z?.le;return!(a&&!P)},cd=a=>{a||=z;if(!a.pf){a.pf=!0;var b=a.le;b.Bf=b.getExtension("WEBGL_multi_draw");b.zf=b.getExtension("EXT_polygon_offset_clamp");b.yf=b.getExtension("EXT_clip_control");b.Df=b.getExtension("WEBGL_polygon_mode");Ic(b);Jc(b);Kc(b);b.Re=b.getExtension("WEBGL_draw_instanced_base_vertex_base_instance");
b.Te=b.getExtension("WEBGL_multi_draw_instanced_base_vertex_base_instance");2<=a.version&&(b.me=b.getExtension("EXT_disjoint_timer_query_webgl2"));if(2>a.version||!b.me)b.me=b.getExtension("EXT_disjoint_timer_query");Lc(b).forEach(c=>{c.includes("lose_context")||c.includes("debug")||b.getExtension(c)})}},z,S,dd=(a,b)=>{P.bindFramebuffer(a,Pc[b])},ed=a=>{P.bindVertexArray(Sc[a])},fd=a=>P.clear(a),gd=(a,b,c,e)=>P.clearColor(a,b,c,e),hd=a=>P.clearStencil(a),jd=(a,b)=>{for(var c=0;c<a;c++){var e=D[b+
4*c>>2];P.deleteVertexArray(Sc[e]);Sc[e]=null}},kd=[],ld=(a,b)=>{ad(a,b,"createVertexArray",Sc)};function md(){var a=Lc(P);return a=a.concat(a.map(b=>"GL_"+b))}
var nd=(a,b,c)=>{if(b){var e=void 0;switch(a){case 36346:e=1;break;case 36344:0!=c&&1!=c&&(S||=1280);return;case 34814:case 36345:e=0;break;case 34466:var f=P.getParameter(34467);e=f?f.length:0;break;case 33309:if(2>z.version){S||=1282;return}e=md().length;break;case 33307:case 33308:if(2>z.version){S||=1280;return}e=33307==a?3:0}if(void 0===e)switch(f=P.getParameter(a),typeof f){case "number":e=f;break;case "boolean":e=f?1:0;break;case "string":S||=1280;return;case "object":if(null===f)switch(a){case 34964:case 35725:case 34965:case 36006:case 36007:case 32873:case 34229:case 36662:case 36663:case 35053:case 35055:case 36010:case 35097:case 35869:case 32874:case 36389:case 35983:case 35368:case 34068:e=
0;break;default:S||=1280;return}else{if(f instanceof Float32Array||f instanceof Uint32Array||f instanceof Int32Array||f instanceof Array){for(a=0;a<f.length;++a)switch(c){case 0:D[b+4*a>>2]=f[a];break;case 2:J[b+4*a>>2]=f[a];break;case 4:Ca[b+a]=f[a]?1:0}return}try{e=f.name|0}catch(h){S||=1280;ya(`GL_INVALID_ENUM in glGet${c}v: Unknown object returned from WebGL getParameter(${a})! (error: ${h})`);return}}break;default:S||=1280;ya(`GL_INVALID_ENUM in glGet${c}v: Native code calling glGet${c}v(${a}) and it returns ${f} of type ${typeof f}!`);
return}switch(c){case 1:c=e;G[b>>2]=c;G[b+4>>2]=(c-G[b>>2])/4294967296;break;case 0:D[b>>2]=e;break;case 2:J[b>>2]=e;break;case 4:Ca[b]=e?1:0}}else S||=1281},od=(a,b)=>nd(a,b,0),pd=(a,b,c)=>{if(c){a=Tc[a];b=2>z.version?P.me.getQueryObjectEXT(a,b):P.getQueryParameter(a,b);var e;"boolean"==typeof b?e=b?1:0:e=b;G[c>>2]=e;G[c+4>>2]=(e-G[c>>2])/4294967296}else S||=1281},rd=a=>{var b=qa(a)+1,c=qd(b);c&&ra(a,c,b);return c},sd=a=>{var b=Xc[a];if(!b){switch(a){case 7939:b=rd(md().join(" "));break;case 7936:case 7937:case 37445:case 37446:(b=
P.getParameter(a))||(S||=1280);b=b?rd(b):0;break;case 7938:b=P.getParameter(7938);var c=`OpenGL ES 2.0 (${b})`;2<=z.version&&(c=`OpenGL ES 3.0 (${b})`);b=rd(c);break;case 35724:b=P.getParameter(35724);c=b.match(/^WebGL GLSL ES ([0-9]\.[0-9][0-9]?)(?:$| .*)/);null!==c&&(3==c[1].length&&(c[1]+="0"),b=`OpenGL ES GLSL ES ${c[1]} (${b})`);b=rd(b);break;default:S||=1280}Xc[a]=b}return b},td=(a,b)=>{if(2>z.version)return S||=1282,0;var c=Yc[a];if(c)return 0>b||b>=c.length?(S||=1281,0):c[b];switch(a){case 7939:return c=
md().map(rd),c=Yc[a]=c,0>b||b>=c.length?(S||=1281,0):c[b];default:return S||=1280,0}},ud=a=>"]"==a.slice(-1)&&a.lastIndexOf("["),vd=a=>{a-=5120;return 0==a?Ca:1==a?A:2==a?Da:4==a?D:6==a?J:5==a||28922==a||28520==a||30779==a||30782==a?G:Ea},wd=(a,b,c,e,f)=>{a=vd(a);b=e*(($c||c)*({5:3,6:4,8:2,29502:3,29504:4,26917:2,26918:2,29846:3,29847:4}[b-6402]||1)*a.BYTES_PER_ELEMENT+Zc-1&-Zc);return a.subarray(f>>>31-Math.clz32(a.BYTES_PER_ELEMENT),f+b>>>31-Math.clz32(a.BYTES_PER_ELEMENT))},W=a=>{var b=P.df;if(b){var c=
b.xe[a];"number"==typeof c&&(b.xe[a]=c=P.getUniformLocation(b,b.Ve[a]+(0<c?`[${c}]`:"")));return c}S||=1282},xd=[],yd=[],zd={},Bd=()=>{if(!Ad){var a={USER:"web_user",LOGNAME:"web_user",PATH:"/",PWD:"/",HOME:"/home/web_user",LANG:("object"==typeof navigator&&navigator.languages&&navigator.languages[0]||"C").replace("-","_")+".UTF-8",_:"./this.program"},b;for(b in zd)void 0===zd[b]?delete a[b]:a[b]=zd[b];var c=[];for(b in a)c.push(`${b}=${a[b]}`);Ad=c}return Ad},Ad,Cd=[null,[],[]];
kb=q.InternalError=class extends Error{constructor(a){super(a);this.name="InternalError"}};for(var Dd=Array(256),Ed=0;256>Ed;++Ed)Dd[Ed]=String.fromCharCode(Ed);nb=Dd;M=q.BindingError=class extends Error{constructor(a){super(a);this.name="BindingError"}};
Object.assign(Eb.prototype,{isAliasOf:function(a){if(!(this instanceof Eb&&a instanceof Eb))return!1;var b=this.Yd.de.be,c=this.Yd.ae;a.Yd=a.Yd;var e=a.Yd.de.be;for(a=a.Yd.ae;b.ge;)c=b.ye(c),b=b.ge;for(;e.ge;)a=e.ye(a),e=e.ge;return b===e&&c===a},clone:function(){this.Yd.ae||pb(this);if(this.Yd.we)return this.Yd.count.value+=1,this;var a=Bb,b=Object,c=b.create,e=Object.getPrototypeOf(this),f=this.Yd;a=a(c.call(b,e,{Yd:{value:{count:f.count,ve:f.ve,we:f.we,ae:f.ae,de:f.de,ee:f.ee,ie:f.ie}}}));a.Yd.count.value+=
1;a.Yd.ve=!1;return a},["delete"](){this.Yd.ae||pb(this);if(this.Yd.ve&&!this.Yd.we)throw new M("Object already scheduled for deletion");rb(this);var a=this.Yd;--a.count.value;0===a.count.value&&(a.ee?a.ie.ne(a.ee):a.de.be.ne(a.ae));this.Yd.we||(this.Yd.ee=void 0,this.Yd.ae=void 0)},isDeleted:function(){return!this.Yd.ae},deleteLater:function(){this.Yd.ae||pb(this);if(this.Yd.ve&&!this.Yd.we)throw new M("Object already scheduled for deletion");Db.push(this);this.Yd.ve=!0;return this}});
Object.assign(Qb.prototype,{jf(a){this.Ue&&(a=this.Ue(a));return a},Qe(a){this.ne?.(a)},je:8,readValueFromPointer:gb,fromWireType:function(a){function b(){return this.Fe?Cb(this.be.se,{de:this.qf,ae:c,ie:this,ee:a}):Cb(this.be.se,{de:this,ae:a})}var c=this.jf(a);if(!c)return this.Qe(a),null;var e=Ab(this.be,c);if(void 0!==e){if(0===e.Yd.count.value)return e.Yd.ae=c,e.Yd.ee=a,e.clone();e=e.clone();this.Qe(a);return e}e=this.be.hf(c);e=tb[e];if(!e)return b.call(this);e=this.Ee?e.cf:e.pointerType;var f=
sb(c,this.be,e.be);return null===f?b.call(this):this.Fe?Cb(e.be.se,{de:e,ae:f,ie:this,ee:a}):Cb(e.be.se,{de:e,ae:f})}});bc=q.UnboundTypeError=((a,b)=>{var c=Fb(b,function(e){this.name=b;this.message=e;e=Error(e).stack;void 0!==e&&(this.stack=this.toString()+"\n"+e.replace(/^Error(:[^\n]*)?\n/,""))});c.prototype=Object.create(a.prototype);c.prototype.constructor=c;c.prototype.toString=function(){return void 0===this.message?this.name:`${this.name}: ${this.message}`};return c})(Error,"UnboundTypeError");
lc.push(0,1,void 0,1,null,1,!0,1,!1,1);q.count_emval_handles=()=>lc.length/2-5-kc.length;for(var Fd=0;32>Fd;++Fd)kd.push(Array(Fd));var Gd=new Float32Array(288);for(Fd=0;288>=Fd;++Fd)xd[Fd]=Gd.subarray(0,Fd);var Hd=new Int32Array(288);for(Fd=0;288>=Fd;++Fd)yd[Fd]=Hd.subarray(0,Fd);
var Wd={F:(a,b,c)=>{var e=new Ya(a);G[e.ae+16>>2]=0;G[e.ae+4>>2]=b;G[e.ae+8>>2]=c;Za=a;$a++;throw Za;},V:function(){return 0},vd:()=>{},ud:function(){return 0},td:()=>{},sd:()=>{},U:function(){},rd:()=>{},nd:()=>{Pa("")},B:a=>{var b=eb[a];delete eb[a];var c=b.Ne,e=b.ne,f=b.Se,h=f.map(l=>l.mf).concat(f.map(l=>l.uf));mb([a],h,l=>{var p={};f.forEach((t,v)=>{var y=l[v],C=t.kf,H=t.lf,I=l[v+f.length],R=t.tf,Q=t.vf;p[t.gf]={read:ba=>y.fromWireType(C(H,ba)),write:(ba,ma)=>{var Y=[];R(Q,ba,I.toWireType(Y,
ma));fb(Y)}}});return[{name:b.name,fromWireType:t=>{var v={},y;for(y in p)v[y]=p[y].read(t);e(t);return v},toWireType:(t,v)=>{for(var y in p)if(!(y in v))throw new TypeError(`Missing field: "${y}"`);var C=c();for(y in p)p[y].write(C,v[y]);null!==t&&t.push(e,C);return C},je:8,readValueFromPointer:gb,ke:e}]})},Y:()=>{},md:(a,b,c,e)=>{b=L(b);lb(a,{name:b,fromWireType:function(f){return!!f},toWireType:function(f,h){return h?c:e},je:8,readValueFromPointer:function(f){return this.fromWireType(A[f])},ke:null})},
j:(a,b,c,e,f,h,l,p,t,v,y,C,H)=>{y=L(y);h=Ub(f,h);p&&=Ub(l,p);v&&=Ub(t,v);H=Ub(C,H);var I=Ib(y);Hb(I,function(){fc(`Cannot construct ${y} due to unbound types`,[e])});mb([a,b,c],e?[e]:[],R=>{R=R[0];if(e){var Q=R.be;var ba=Q.se}else ba=Eb.prototype;R=Fb(y,function(...Fa){if(Object.getPrototypeOf(this)!==ma)throw new M("Use 'new' to construct "+y);if(void 0===Y.pe)throw new M(y+" has no accessible constructor");var ca=Y.pe[Fa.length];if(void 0===ca)throw new M(`Tried to invoke ctor of ${y} with invalid number of parameters (${Fa.length}) - expected (${Object.keys(Y.pe).toString()}) parameters instead!`);
return ca.apply(this,Fa)});var ma=Object.create(ba,{constructor:{value:R}});R.prototype=ma;var Y=new Jb(y,R,ma,H,Q,h,p,v);if(Y.ge){var ia;(ia=Y.ge).ze??(ia.ze=[]);Y.ge.ze.push(Y)}Q=new Qb(y,Y,!0,!1,!1);ia=new Qb(y+"*",Y,!1,!1,!1);ba=new Qb(y+" const*",Y,!1,!0,!1);tb[a]={pointerType:ia,cf:ba};Rb(I,R);return[Q,ia,ba]})},e:(a,b,c,e,f,h,l)=>{var p=ic(c,e);b=L(b);b=jc(b);h=Ub(f,h);mb([],[a],t=>{function v(){fc(`Cannot call ${y} due to unbound types`,p)}t=t[0];var y=`${t.name}.${b}`;b.startsWith("@@")&&
(b=Symbol[b.substring(2)]);var C=t.be.constructor;void 0===C[b]?(v.oe=c-1,C[b]=v):(Gb(C,b,y),C[b].fe[c-1]=v);mb([],p,H=>{H=[H[0],null].concat(H.slice(1));H=hc(y,H,null,h,l);void 0===C[b].fe?(H.oe=c-1,C[b]=H):C[b].fe[c-1]=H;if(t.be.ze)for(const I of t.be.ze)I.constructor.hasOwnProperty(b)||(I.constructor[b]=H);return[]});return[]})},x:(a,b,c,e,f,h)=>{var l=ic(b,c);f=Ub(e,f);mb([],[a],p=>{p=p[0];var t=`constructor ${p.name}`;void 0===p.be.pe&&(p.be.pe=[]);if(void 0!==p.be.pe[b-1])throw new M(`Cannot register multiple constructors with identical number of parameters (${b-
1}) for class '${p.name}'! Overload resolution is currently only performed using the parameter count, not actual type info!`);p.be.pe[b-1]=()=>{fc(`Cannot construct ${p.name} due to unbound types`,l)};mb([],l,v=>{v.splice(1,0,null);p.be.pe[b-1]=hc(t,v,null,f,h);return[]});return[]})},a:(a,b,c,e,f,h,l,p)=>{var t=ic(c,e);b=L(b);b=jc(b);h=Ub(f,h);mb([],[a],v=>{function y(){fc(`Cannot call ${C} due to unbound types`,t)}v=v[0];var C=`${v.name}.${b}`;b.startsWith("@@")&&(b=Symbol[b.substring(2)]);p&&v.be.rf.push(b);
var H=v.be.se,I=H[b];void 0===I||void 0===I.fe&&I.className!==v.name&&I.oe===c-2?(y.oe=c-2,y.className=v.name,H[b]=y):(Gb(H,b,C),H[b].fe[c-2]=y);mb([],t,R=>{R=hc(C,R,v,h,l);void 0===H[b].fe?(R.oe=c-2,H[b]=R):H[b].fe[c-2]=R;return[]});return[]})},q:(a,b,c)=>{a=L(a);mb([],[b],e=>{e=e[0];q[a]=e.fromWireType(c);return[]})},ld:a=>lb(a,oc),i:(a,b,c,e)=>{function f(){}b=L(b);f.values={};lb(a,{name:b,constructor:f,fromWireType:function(h){return this.constructor.values[h]},toWireType:(h,l)=>l.value,je:8,
readValueFromPointer:pc(b,c,e),ke:null});Hb(b,f)},b:(a,b,c)=>{var e=qc(a,"enum");b=L(b);a=e.constructor;e=Object.create(e.constructor.prototype,{value:{value:c},constructor:{value:Fb(`${e.name}_${b}`,function(){})}});a.values[c]=e;a[b]=e},S:(a,b,c)=>{b=L(b);lb(a,{name:b,fromWireType:e=>e,toWireType:(e,f)=>f,je:8,readValueFromPointer:rc(b,c),ke:null})},w:(a,b,c,e,f,h)=>{var l=ic(b,c);a=L(a);a=jc(a);f=Ub(e,f);Hb(a,function(){fc(`Cannot call ${a} due to unbound types`,l)},b-1);mb([],l,p=>{p=[p[0],null].concat(p.slice(1));
Rb(a,hc(a,p,null,f,h),b-1);return[]})},C:(a,b,c,e,f)=>{b=L(b);-1===f&&(f=4294967295);f=p=>p;if(0===e){var h=32-8*c;f=p=>p<<h>>>h}var l=b.includes("unsigned")?function(p,t){return t>>>0}:function(p,t){return t};lb(a,{name:b,fromWireType:f,toWireType:l,je:8,readValueFromPointer:sc(b,c,0!==e),ke:null})},p:(a,b,c)=>{function e(h){return new f(Ca.buffer,G[h+4>>2],G[h>>2])}var f=[Int8Array,Uint8Array,Int16Array,Uint16Array,Int32Array,Uint32Array,Float32Array,Float64Array][b];c=L(c);lb(a,{name:c,fromWireType:e,
je:8,readValueFromPointer:e},{nf:!0})},o:(a,b,c,e,f,h,l,p,t,v,y,C)=>{c=L(c);h=Ub(f,h);p=Ub(l,p);v=Ub(t,v);C=Ub(y,C);mb([a],[b],H=>{H=H[0];return[new Qb(c,H.be,!1,!1,!0,H,e,h,p,v,C)]})},R:(a,b)=>{b=L(b);var c="std::string"===b;lb(a,{name:b,fromWireType:function(e){var f=G[e>>2],h=e+4;if(c)for(var l=h,p=0;p<=f;++p){var t=h+p;if(p==f||0==A[t]){l=l?db(A,l,t-l):"";if(void 0===v)var v=l;else v+=String.fromCharCode(0),v+=l;l=t+1}}else{v=Array(f);for(p=0;p<f;++p)v[p]=String.fromCharCode(A[h+p]);v=v.join("")}dc(e);
return v},toWireType:function(e,f){f instanceof ArrayBuffer&&(f=new Uint8Array(f));var h="string"==typeof f;if(!(h||f instanceof Uint8Array||f instanceof Uint8ClampedArray||f instanceof Int8Array))throw new M("Cannot pass non-string to std::string");var l=c&&h?qa(f):f.length;var p=qd(4+l+1),t=p+4;G[p>>2]=l;if(c&&h)ra(f,t,l+1);else if(h)for(h=0;h<l;++h){var v=f.charCodeAt(h);if(255<v)throw dc(t),new M("String has UTF-16 code units that do not fit in 8 bits");A[t+h]=v}else for(h=0;h<l;++h)A[t+h]=f[h];
null!==e&&e.push(dc,p);return p},je:8,readValueFromPointer:gb,ke(e){dc(e)}})},M:(a,b,c)=>{c=L(c);if(2===b){var e=uc;var f=vc;var h=wc;var l=p=>Ea[p>>1]}else 4===b&&(e=xc,f=yc,h=zc,l=p=>G[p>>2]);lb(a,{name:c,fromWireType:p=>{for(var t=G[p>>2],v,y=p+4,C=0;C<=t;++C){var H=p+4+C*b;if(C==t||0==l(H))y=e(y,H-y),void 0===v?v=y:(v+=String.fromCharCode(0),v+=y),y=H+b}dc(p);return v},toWireType:(p,t)=>{if("string"!=typeof t)throw new M(`Cannot pass non-string to C++ string type ${c}`);var v=h(t),y=qd(4+v+b);
G[y>>2]=v/b;f(t,y+4,v+b);null!==p&&p.push(dc,y);return y},je:8,readValueFromPointer:gb,ke(p){dc(p)}})},A:(a,b,c,e,f,h)=>{eb[a]={name:L(b),Ne:Ub(c,e),ne:Ub(f,h),Se:[]}},d:(a,b,c,e,f,h,l,p,t,v)=>{eb[a].Se.push({gf:L(b),mf:c,kf:Ub(e,f),lf:h,uf:l,tf:Ub(p,t),vf:v})},kd:(a,b)=>{b=L(b);lb(a,{Af:!0,name:b,je:0,fromWireType:()=>{},toWireType:()=>{}})},jd:()=>1,id:()=>{throw Infinity;},E:(a,b,c)=>{a=nc(a);b=qc(b,"emval::as");return Ac(b,c,a)},L:(a,b,c,e)=>{a=Bc[a];b=nc(b);return a(null,b,c,e)},s:(a,b,c,e,f)=>
{a=Bc[a];b=nc(b);c=Dc(c);return a(b,b[c],e,f)},c:mc,K:a=>{if(0===a)return Ob(Ec());a=Dc(a);return Ob(Ec()[a])},n:(a,b,c)=>{var e=Gc(a,b),f=e.shift();a--;var h=Array(a);b=`methodCaller<(${e.map(l=>l.name).join(", ")}) => ${f.name}>`;return Fc(Fb(b,(l,p,t,v)=>{for(var y=0,C=0;C<a;++C)h[C]=e[C].readValueFromPointer(v+y),y+=e[C].je;l=1===c?Hc(p,h):p.apply(l,h);return Ac(f,t,l)}))},z:(a,b)=>{a=nc(a);b=nc(b);return Ob(a[b])},H:a=>{9<a&&(lc[a+1]+=1)},G:()=>Ob([]),f:a=>Ob(Dc(a)),D:()=>Ob({}),hd:a=>{a=nc(a);
return!a},k:a=>{var b=nc(a);fb(b);mc(a)},h:(a,b,c)=>{a=nc(a);b=nc(b);c=nc(c);a[b]=c},g:(a,b)=>{a=qc(a,"_emval_take_value");a=a.readValueFromPointer(b);return Ob(a)},X:function(){return-52},W:function(){},gd:(a,b,c,e)=>{var f=(new Date).getFullYear(),h=(new Date(f,0,1)).getTimezoneOffset();f=(new Date(f,6,1)).getTimezoneOffset();G[a>>2]=60*Math.max(h,f);D[b>>2]=Number(h!=f);b=l=>{var p=Math.abs(l);return`UTC${0<=l?"-":"+"}${String(Math.floor(p/60)).padStart(2,"0")}${String(p%60).padStart(2,"0")}`};
a=b(h);b=b(f);f<h?(ra(a,c,17),ra(b,e,17)):(ra(a,e,17),ra(b,c,17))},fd:()=>performance.now(),ed:a=>P.activeTexture(a),dd:(a,b)=>{P.attachShader(Oc[a],Rc[b])},cd:(a,b)=>{P.beginQuery(a,Tc[b])},bd:(a,b)=>{P.me.beginQueryEXT(a,Tc[b])},ad:(a,b,c)=>{P.bindAttribLocation(Oc[a],b,c?db(A,c):"")},$c:(a,b)=>{35051==a?P.Ke=b:35052==a&&(P.re=b);P.bindBuffer(a,Nc[b])},_c:dd,Zc:(a,b)=>{P.bindRenderbuffer(a,Qc[b])},Yc:(a,b)=>{P.bindSampler(a,Uc[b])},Xc:(a,b)=>{P.bindTexture(a,ka[b])},Wc:ed,Vc:ed,Uc:(a,b,c,e)=>P.blendColor(a,
b,c,e),Tc:a=>P.blendEquation(a),Sc:(a,b)=>P.blendFunc(a,b),Rc:(a,b,c,e,f,h,l,p,t,v)=>P.blitFramebuffer(a,b,c,e,f,h,l,p,t,v),Qc:(a,b,c,e)=>{2<=z.version?c&&b?P.bufferData(a,A,e,c,b):P.bufferData(a,b,e):P.bufferData(a,c?A.subarray(c,c+b):b,e)},Pc:(a,b,c,e)=>{2<=z.version?c&&P.bufferSubData(a,b,A,e,c):P.bufferSubData(a,b,A.subarray(e,e+c))},Oc:a=>P.checkFramebufferStatus(a),Nc:fd,Mc:gd,Lc:hd,Kc:(a,b,c,e)=>P.clientWaitSync(Vc[a],b,(c>>>0)+4294967296*e),Jc:(a,b,c,e)=>{P.colorMask(!!a,!!b,!!c,!!e)},Ic:a=>
{P.compileShader(Rc[a])},Hc:(a,b,c,e,f,h,l,p)=>{2<=z.version?P.re||!l?P.compressedTexImage2D(a,b,c,e,f,h,l,p):P.compressedTexImage2D(a,b,c,e,f,h,A,p,l):P.compressedTexImage2D(a,b,c,e,f,h,A.subarray(p,p+l))},Gc:(a,b,c,e,f,h,l,p,t)=>{2<=z.version?P.re||!p?P.compressedTexSubImage2D(a,b,c,e,f,h,l,p,t):P.compressedTexSubImage2D(a,b,c,e,f,h,l,A,t,p):P.compressedTexSubImage2D(a,b,c,e,f,h,l,A.subarray(t,t+p))},Fc:(a,b,c,e,f)=>P.copyBufferSubData(a,b,c,e,f),Ec:(a,b,c,e,f,h,l,p)=>P.copyTexSubImage2D(a,b,c,
e,f,h,l,p),Dc:()=>{var a=ja(Oc),b=P.createProgram();b.name=a;b.Ie=b.Ge=b.He=0;b.Oe=1;Oc[a]=b;return a},Cc:a=>{var b=ja(Rc);Rc[b]=P.createShader(a);return b},Bc:a=>P.cullFace(a),Ac:(a,b)=>{for(var c=0;c<a;c++){var e=D[b+4*c>>2],f=Nc[e];f&&(P.deleteBuffer(f),f.name=0,Nc[e]=null,e==P.Ke&&(P.Ke=0),e==P.re&&(P.re=0))}},zc:(a,b)=>{for(var c=0;c<a;++c){var e=D[b+4*c>>2],f=Pc[e];f&&(P.deleteFramebuffer(f),f.name=0,Pc[e]=null)}},yc:a=>{if(a){var b=Oc[a];b?(P.deleteProgram(b),b.name=0,Oc[a]=null):S||=1281}},
xc:(a,b)=>{for(var c=0;c<a;c++){var e=D[b+4*c>>2],f=Tc[e];f&&(P.deleteQuery(f),Tc[e]=null)}},wc:(a,b)=>{for(var c=0;c<a;c++){var e=D[b+4*c>>2],f=Tc[e];f&&(P.me.deleteQueryEXT(f),Tc[e]=null)}},vc:(a,b)=>{for(var c=0;c<a;c++){var e=D[b+4*c>>2],f=Qc[e];f&&(P.deleteRenderbuffer(f),f.name=0,Qc[e]=null)}},uc:(a,b)=>{for(var c=0;c<a;c++){var e=D[b+4*c>>2],f=Uc[e];f&&(P.deleteSampler(f),f.name=0,Uc[e]=null)}},tc:a=>{if(a){var b=Rc[a];b?(P.deleteShader(b),Rc[a]=null):S||=1281}},sc:a=>{if(a){var b=Vc[a];b?
(P.deleteSync(b),b.name=0,Vc[a]=null):S||=1281}},rc:(a,b)=>{for(var c=0;c<a;c++){var e=D[b+4*c>>2],f=ka[e];f&&(P.deleteTexture(f),f.name=0,ka[e]=null)}},qc:jd,pc:jd,oc:a=>{P.depthMask(!!a)},nc:a=>P.disable(a),mc:a=>{P.disableVertexAttribArray(a)},lc:(a,b,c)=>{P.drawArrays(a,b,c)},kc:(a,b,c,e)=>{P.drawArraysInstanced(a,b,c,e)},jc:(a,b,c,e,f)=>{P.Re.drawArraysInstancedBaseInstanceWEBGL(a,b,c,e,f)},ic:(a,b)=>{for(var c=kd[a],e=0;e<a;e++)c[e]=D[b+4*e>>2];P.drawBuffers(c)},hc:(a,b,c,e)=>{P.drawElements(a,
b,c,e)},gc:(a,b,c,e,f)=>{P.drawElementsInstanced(a,b,c,e,f)},fc:(a,b,c,e,f,h,l)=>{P.Re.drawElementsInstancedBaseVertexBaseInstanceWEBGL(a,b,c,e,f,h,l)},ec:(a,b,c,e,f,h)=>{P.drawElements(a,e,f,h)},dc:a=>P.enable(a),cc:a=>{P.enableVertexAttribArray(a)},bc:a=>P.endQuery(a),ac:a=>{P.me.endQueryEXT(a)},$b:(a,b)=>(a=P.fenceSync(a,b))?(b=ja(Vc),a.name=b,Vc[b]=a,b):0,_b:()=>P.finish(),Zb:()=>P.flush(),Yb:(a,b,c,e)=>{P.framebufferRenderbuffer(a,b,c,Qc[e])},Xb:(a,b,c,e,f)=>{P.framebufferTexture2D(a,b,c,ka[e],
f)},Wb:a=>P.frontFace(a),Vb:(a,b)=>{ad(a,b,"createBuffer",Nc)},Ub:(a,b)=>{ad(a,b,"createFramebuffer",Pc)},Tb:(a,b)=>{ad(a,b,"createQuery",Tc)},Sb:(a,b)=>{for(var c=0;c<a;c++){var e=P.me.createQueryEXT();if(!e){for(S||=1282;c<a;)D[b+4*c++>>2]=0;break}var f=ja(Tc);e.name=f;Tc[f]=e;D[b+4*c>>2]=f}},Rb:(a,b)=>{ad(a,b,"createRenderbuffer",Qc)},Qb:(a,b)=>{ad(a,b,"createSampler",Uc)},Pb:(a,b)=>{ad(a,b,"createTexture",ka)},Ob:ld,Nb:ld,Mb:a=>P.generateMipmap(a),Lb:(a,b,c)=>{c?D[c>>2]=P.getBufferParameter(a,
b):S||=1281},Kb:()=>{var a=P.getError()||S;S=0;return a},Jb:(a,b)=>nd(a,b,2),Ib:(a,b,c,e)=>{a=P.getFramebufferAttachmentParameter(a,b,c);if(a instanceof WebGLRenderbuffer||a instanceof WebGLTexture)a=a.name|0;D[e>>2]=a},Hb:od,Gb:(a,b,c,e)=>{a=P.getProgramInfoLog(Oc[a]);null===a&&(a="(unknown error)");b=0<b&&e?ra(a,e,b):0;c&&(D[c>>2]=b)},Fb:(a,b,c)=>{if(c)if(a>=Mc)S||=1281;else if(a=Oc[a],35716==b)a=P.getProgramInfoLog(a),null===a&&(a="(unknown error)"),D[c>>2]=a.length+1;else if(35719==b){if(!a.Ie){var e=
P.getProgramParameter(a,35718);for(b=0;b<e;++b)a.Ie=Math.max(a.Ie,P.getActiveUniform(a,b).name.length+1)}D[c>>2]=a.Ie}else if(35722==b){if(!a.Ge)for(e=P.getProgramParameter(a,35721),b=0;b<e;++b)a.Ge=Math.max(a.Ge,P.getActiveAttrib(a,b).name.length+1);D[c>>2]=a.Ge}else if(35381==b){if(!a.He)for(e=P.getProgramParameter(a,35382),b=0;b<e;++b)a.He=Math.max(a.He,P.getActiveUniformBlockName(a,b).length+1);D[c>>2]=a.He}else D[c>>2]=P.getProgramParameter(a,b);else S||=1281},Eb:pd,Db:pd,Cb:(a,b,c)=>{if(c){a=
P.getQueryParameter(Tc[a],b);var e;"boolean"==typeof a?e=a?1:0:e=a;D[c>>2]=e}else S||=1281},Bb:(a,b,c)=>{if(c){a=P.me.getQueryObjectEXT(Tc[a],b);var e;"boolean"==typeof a?e=a?1:0:e=a;D[c>>2]=e}else S||=1281},Ab:(a,b,c)=>{c?D[c>>2]=P.getQuery(a,b):S||=1281},zb:(a,b,c)=>{c?D[c>>2]=P.me.getQueryEXT(a,b):S||=1281},yb:(a,b,c)=>{c?D[c>>2]=P.getRenderbufferParameter(a,b):S||=1281},xb:(a,b,c,e)=>{a=P.getShaderInfoLog(Rc[a]);null===a&&(a="(unknown error)");b=0<b&&e?ra(a,e,b):0;c&&(D[c>>2]=b)},wb:(a,b,c,e)=>
{a=P.getShaderPrecisionFormat(a,b);D[c>>2]=a.rangeMin;D[c+4>>2]=a.rangeMax;D[e>>2]=a.precision},vb:(a,b,c)=>{c?35716==b?(a=P.getShaderInfoLog(Rc[a]),null===a&&(a="(unknown error)"),D[c>>2]=a?a.length+1:0):35720==b?(a=P.getShaderSource(Rc[a]),D[c>>2]=a?a.length+1:0):D[c>>2]=P.getShaderParameter(Rc[a],b):S||=1281},ub:sd,tb:td,sb:(a,b)=>{b=b?db(A,b):"";if(a=Oc[a]){var c=a,e=c.xe,f=c.We,h;if(!e){c.xe=e={};c.Ve={};var l=P.getProgramParameter(c,35718);for(h=0;h<l;++h){var p=P.getActiveUniform(c,h);var t=
p.name;p=p.size;var v=ud(t);v=0<v?t.slice(0,v):t;var y=c.Oe;c.Oe+=p;f[v]=[p,y];for(t=0;t<p;++t)e[y]=t,c.Ve[y++]=v}}c=a.xe;e=0;f=b;h=ud(b);0<h&&(e=parseInt(b.slice(h+1))>>>0,f=b.slice(0,h));if((f=a.We[f])&&e<f[0]&&(e+=f[1],c[e]=c[e]||P.getUniformLocation(a,b)))return e}else S||=1281;return-1},rb:(a,b,c)=>{for(var e=kd[b],f=0;f<b;f++)e[f]=D[c+4*f>>2];P.invalidateFramebuffer(a,e)},qb:(a,b,c,e,f,h,l)=>{for(var p=kd[b],t=0;t<b;t++)p[t]=D[c+4*t>>2];P.invalidateSubFramebuffer(a,p,e,f,h,l)},pb:a=>P.isSync(Vc[a]),
ob:a=>(a=ka[a])?P.isTexture(a):0,nb:a=>P.lineWidth(a),mb:a=>{a=Oc[a];P.linkProgram(a);a.xe=0;a.We={}},lb:(a,b,c,e,f,h)=>{P.Te.multiDrawArraysInstancedBaseInstanceWEBGL(a,D,b>>2,D,c>>2,D,e>>2,G,f>>2,h)},kb:(a,b,c,e,f,h,l,p)=>{P.Te.multiDrawElementsInstancedBaseVertexBaseInstanceWEBGL(a,D,b>>2,c,D,e>>2,D,f>>2,D,h>>2,G,l>>2,p)},jb:(a,b)=>{3317==a?Zc=b:3314==a&&($c=b);P.pixelStorei(a,b)},ib:(a,b)=>{P.me.queryCounterEXT(Tc[a],b)},hb:a=>P.readBuffer(a),gb:(a,b,c,e,f,h,l)=>{if(2<=z.version)if(P.Ke)P.readPixels(a,
b,c,e,f,h,l);else{var p=vd(h);l>>>=31-Math.clz32(p.BYTES_PER_ELEMENT);P.readPixels(a,b,c,e,f,h,p,l)}else(p=wd(h,f,c,e,l))?P.readPixels(a,b,c,e,f,h,p):S||=1280},fb:(a,b,c,e)=>P.renderbufferStorage(a,b,c,e),eb:(a,b,c,e,f)=>P.renderbufferStorageMultisample(a,b,c,e,f),db:(a,b,c)=>{P.samplerParameterf(Uc[a],b,c)},cb:(a,b,c)=>{P.samplerParameteri(Uc[a],b,c)},bb:(a,b,c)=>{P.samplerParameteri(Uc[a],b,D[c>>2])},ab:(a,b,c,e)=>P.scissor(a,b,c,e),$a:(a,b,c,e)=>{for(var f="",h=0;h<b;++h){var l=(l=G[c+4*h>>2])?
db(A,l,e?G[e+4*h>>2]:void 0):"";f+=l}P.shaderSource(Rc[a],f)},_a:(a,b,c)=>P.stencilFunc(a,b,c),Za:(a,b,c,e)=>P.stencilFuncSeparate(a,b,c,e),Ya:a=>P.stencilMask(a),Xa:(a,b)=>P.stencilMaskSeparate(a,b),Wa:(a,b,c)=>P.stencilOp(a,b,c),Va:(a,b,c,e)=>P.stencilOpSeparate(a,b,c,e),Ua:(a,b,c,e,f,h,l,p,t)=>{if(2<=z.version){if(P.re){P.texImage2D(a,b,c,e,f,h,l,p,t);return}if(t){var v=vd(p);t>>>=31-Math.clz32(v.BYTES_PER_ELEMENT);P.texImage2D(a,b,c,e,f,h,l,p,v,t);return}}v=t?wd(p,l,e,f,t):null;P.texImage2D(a,
b,c,e,f,h,l,p,v)},Ta:(a,b,c)=>P.texParameterf(a,b,c),Sa:(a,b,c)=>{P.texParameterf(a,b,J[c>>2])},Ra:(a,b,c)=>P.texParameteri(a,b,c),Qa:(a,b,c)=>{P.texParameteri(a,b,D[c>>2])},Pa:(a,b,c,e,f)=>P.texStorage2D(a,b,c,e,f),Oa:(a,b,c,e,f,h,l,p,t)=>{if(2<=z.version){if(P.re){P.texSubImage2D(a,b,c,e,f,h,l,p,t);return}if(t){var v=vd(p);P.texSubImage2D(a,b,c,e,f,h,l,p,v,t>>>31-Math.clz32(v.BYTES_PER_ELEMENT));return}}t=t?wd(p,l,f,h,t):null;P.texSubImage2D(a,b,c,e,f,h,l,p,t)},Na:(a,b)=>{P.uniform1f(W(a),b)},Ma:(a,
b,c)=>{if(2<=z.version)b&&P.uniform1fv(W(a),J,c>>2,b);else{if(288>=b)for(var e=xd[b],f=0;f<b;++f)e[f]=J[c+4*f>>2];else e=J.subarray(c>>2,c+4*b>>2);P.uniform1fv(W(a),e)}},La:(a,b)=>{P.uniform1i(W(a),b)},Ka:(a,b,c)=>{if(2<=z.version)b&&P.uniform1iv(W(a),D,c>>2,b);else{if(288>=b)for(var e=yd[b],f=0;f<b;++f)e[f]=D[c+4*f>>2];else e=D.subarray(c>>2,c+4*b>>2);P.uniform1iv(W(a),e)}},Ja:(a,b,c)=>{P.uniform2f(W(a),b,c)},Ia:(a,b,c)=>{if(2<=z.version)b&&P.uniform2fv(W(a),J,c>>2,2*b);else{if(144>=b){b*=2;for(var e=
xd[b],f=0;f<b;f+=2)e[f]=J[c+4*f>>2],e[f+1]=J[c+(4*f+4)>>2]}else e=J.subarray(c>>2,c+8*b>>2);P.uniform2fv(W(a),e)}},Ha:(a,b,c)=>{P.uniform2i(W(a),b,c)},Ga:(a,b,c)=>{if(2<=z.version)b&&P.uniform2iv(W(a),D,c>>2,2*b);else{if(144>=b){b*=2;for(var e=yd[b],f=0;f<b;f+=2)e[f]=D[c+4*f>>2],e[f+1]=D[c+(4*f+4)>>2]}else e=D.subarray(c>>2,c+8*b>>2);P.uniform2iv(W(a),e)}},Fa:(a,b,c,e)=>{P.uniform3f(W(a),b,c,e)},Ea:(a,b,c)=>{if(2<=z.version)b&&P.uniform3fv(W(a),J,c>>2,3*b);else{if(96>=b){b*=3;for(var e=xd[b],f=0;f<
b;f+=3)e[f]=J[c+4*f>>2],e[f+1]=J[c+(4*f+4)>>2],e[f+2]=J[c+(4*f+8)>>2]}else e=J.subarray(c>>2,c+12*b>>2);P.uniform3fv(W(a),e)}},Da:(a,b,c,e)=>{P.uniform3i(W(a),b,c,e)},Ca:(a,b,c)=>{if(2<=z.version)b&&P.uniform3iv(W(a),D,c>>2,3*b);else{if(96>=b){b*=3;for(var e=yd[b],f=0;f<b;f+=3)e[f]=D[c+4*f>>2],e[f+1]=D[c+(4*f+4)>>2],e[f+2]=D[c+(4*f+8)>>2]}else e=D.subarray(c>>2,c+12*b>>2);P.uniform3iv(W(a),e)}},Ba:(a,b,c,e,f)=>{P.uniform4f(W(a),b,c,e,f)},Aa:(a,b,c)=>{if(2<=z.version)b&&P.uniform4fv(W(a),J,c>>2,4*
b);else{if(72>=b){var e=xd[4*b],f=J;c>>=2;b*=4;for(var h=0;h<b;h+=4){var l=c+h;e[h]=f[l];e[h+1]=f[l+1];e[h+2]=f[l+2];e[h+3]=f[l+3]}}else e=J.subarray(c>>2,c+16*b>>2);P.uniform4fv(W(a),e)}},za:(a,b,c,e,f)=>{P.uniform4i(W(a),b,c,e,f)},ya:(a,b,c)=>{if(2<=z.version)b&&P.uniform4iv(W(a),D,c>>2,4*b);else{if(72>=b){b*=4;for(var e=yd[b],f=0;f<b;f+=4)e[f]=D[c+4*f>>2],e[f+1]=D[c+(4*f+4)>>2],e[f+2]=D[c+(4*f+8)>>2],e[f+3]=D[c+(4*f+12)>>2]}else e=D.subarray(c>>2,c+16*b>>2);P.uniform4iv(W(a),e)}},xa:(a,b,c,e)=>
{if(2<=z.version)b&&P.uniformMatrix2fv(W(a),!!c,J,e>>2,4*b);else{if(72>=b){b*=4;for(var f=xd[b],h=0;h<b;h+=4)f[h]=J[e+4*h>>2],f[h+1]=J[e+(4*h+4)>>2],f[h+2]=J[e+(4*h+8)>>2],f[h+3]=J[e+(4*h+12)>>2]}else f=J.subarray(e>>2,e+16*b>>2);P.uniformMatrix2fv(W(a),!!c,f)}},wa:(a,b,c,e)=>{if(2<=z.version)b&&P.uniformMatrix3fv(W(a),!!c,J,e>>2,9*b);else{if(32>=b){b*=9;for(var f=xd[b],h=0;h<b;h+=9)f[h]=J[e+4*h>>2],f[h+1]=J[e+(4*h+4)>>2],f[h+2]=J[e+(4*h+8)>>2],f[h+3]=J[e+(4*h+12)>>2],f[h+4]=J[e+(4*h+16)>>2],f[h+
5]=J[e+(4*h+20)>>2],f[h+6]=J[e+(4*h+24)>>2],f[h+7]=J[e+(4*h+28)>>2],f[h+8]=J[e+(4*h+32)>>2]}else f=J.subarray(e>>2,e+36*b>>2);P.uniformMatrix3fv(W(a),!!c,f)}},va:(a,b,c,e)=>{if(2<=z.version)b&&P.uniformMatrix4fv(W(a),!!c,J,e>>2,16*b);else{if(18>=b){var f=xd[16*b],h=J;e>>=2;b*=16;for(var l=0;l<b;l+=16){var p=e+l;f[l]=h[p];f[l+1]=h[p+1];f[l+2]=h[p+2];f[l+3]=h[p+3];f[l+4]=h[p+4];f[l+5]=h[p+5];f[l+6]=h[p+6];f[l+7]=h[p+7];f[l+8]=h[p+8];f[l+9]=h[p+9];f[l+10]=h[p+10];f[l+11]=h[p+11];f[l+12]=h[p+12];f[l+
13]=h[p+13];f[l+14]=h[p+14];f[l+15]=h[p+15]}}else f=J.subarray(e>>2,e+64*b>>2);P.uniformMatrix4fv(W(a),!!c,f)}},ua:a=>{a=Oc[a];P.useProgram(a);P.df=a},ta:(a,b)=>P.vertexAttrib1f(a,b),sa:(a,b)=>{P.vertexAttrib2f(a,J[b>>2],J[b+4>>2])},ra:(a,b)=>{P.vertexAttrib3f(a,J[b>>2],J[b+4>>2],J[b+8>>2])},qa:(a,b)=>{P.vertexAttrib4f(a,J[b>>2],J[b+4>>2],J[b+8>>2],J[b+12>>2])},pa:(a,b)=>{P.vertexAttribDivisor(a,b)},oa:(a,b,c,e,f)=>{P.vertexAttribIPointer(a,b,c,e,f)},na:(a,b,c,e,f,h)=>{P.vertexAttribPointer(a,b,c,
!!e,f,h)},ma:(a,b,c,e)=>P.viewport(a,b,c,e),la:(a,b,c,e)=>{P.waitSync(Vc[a],b,(c>>>0)+4294967296*e)},ka:a=>{var b=A.length;a>>>=0;if(2147483648<a)return!1;for(var c=1;4>=c;c*=2){var e=b*(1+1/c);e=Math.min(e,a+100663296);a:{e=(Math.min(2147483648,65536*Math.ceil(Math.max(a,e)/65536))-za.buffer.byteLength+65535)/65536|0;try{za.grow(e);Ha();var f=1;break a}catch(h){}f=void 0}if(f)return!0}return!1},ja:()=>z?z.handle:0,qd:(a,b)=>{var c=0;Bd().forEach((e,f)=>{var h=b+c;f=G[a+4*f>>2]=h;for(h=0;h<e.length;++h)Ca[f++]=
e.charCodeAt(h);Ca[f]=0;c+=e.length+1});return 0},pd:(a,b)=>{var c=Bd();G[a>>2]=c.length;var e=0;c.forEach(f=>e+=f.length+1);G[b>>2]=e;return 0},ia:a=>{Xa||(Aa=!0);throw new Va(a);},N:()=>52,_:function(){return 52},od:()=>52,Z:function(){return 70},T:(a,b,c,e)=>{for(var f=0,h=0;h<c;h++){var l=G[b>>2],p=G[b+4>>2];b+=8;for(var t=0;t<p;t++){var v=A[l+t],y=Cd[a];0===v||10===v?((1===a?wa:ya)(db(y)),y.length=0):y.push(v)}f+=p}G[e>>2]=f;return 0},ha:dd,ga:fd,fa:gd,ea:hd,J:od,Q:sd,da:td,m:Id,y:Jd,l:Kd,I:Ld,
ca:Md,P:Nd,O:Od,t:Pd,v:Qd,u:Rd,r:Sd,ba:Td,aa:Ud,$:Vd},Z=function(){function a(c){Z=c.exports;za=Z.wd;Ha();O=Z.zd;Ja.unshift(Z.xd);La--;0==La&&(null!==Ma&&(clearInterval(Ma),Ma=null),Oa&&(c=Oa,Oa=null,c()));return Z}var b={a:Wd};La++;if(q.instantiateWasm)try{return q.instantiateWasm(b,a)}catch(c){ya(`Module.instantiateWasm callback failed with error: ${c}`),da(c)}Ra??=q.locateFile?Qa("canvaskit.wasm")?"canvaskit.wasm":ta+"canvaskit.wasm":(new URL("canvaskit.wasm",import.meta.url)).href;
Ua(b,function(c){a(c.instance)}).catch(da);return{}}(),cc=a=>(cc=Z.yd)(a),qd=q._malloc=a=>(qd=q._malloc=Z.Ad)(a),dc=q._free=a=>(dc=q._free=Z.Bd)(a),Xd=(a,b)=>(Xd=Z.Cd)(a,b),Yd=a=>(Yd=Z.Dd)(a),Zd=()=>(Zd=Z.Ed)();q.dynCall_viji=(a,b,c,e,f)=>(q.dynCall_viji=Z.Fd)(a,b,c,e,f);q.dynCall_vijiii=(a,b,c,e,f,h,l)=>(q.dynCall_vijiii=Z.Gd)(a,b,c,e,f,h,l);q.dynCall_viiiiij=(a,b,c,e,f,h,l,p)=>(q.dynCall_viiiiij=Z.Hd)(a,b,c,e,f,h,l,p);q.dynCall_vij=(a,b,c,e)=>(q.dynCall_vij=Z.Id)(a,b,c,e);
q.dynCall_iiiji=(a,b,c,e,f,h)=>(q.dynCall_iiiji=Z.Jd)(a,b,c,e,f,h);q.dynCall_jii=(a,b,c)=>(q.dynCall_jii=Z.Kd)(a,b,c);q.dynCall_jiiiiii=(a,b,c,e,f,h,l)=>(q.dynCall_jiiiiii=Z.Ld)(a,b,c,e,f,h,l);q.dynCall_jiiiiji=(a,b,c,e,f,h,l,p)=>(q.dynCall_jiiiiji=Z.Md)(a,b,c,e,f,h,l,p);q.dynCall_ji=(a,b)=>(q.dynCall_ji=Z.Nd)(a,b);q.dynCall_iijj=(a,b,c,e,f,h)=>(q.dynCall_iijj=Z.Od)(a,b,c,e,f,h);q.dynCall_iiji=(a,b,c,e,f)=>(q.dynCall_iiji=Z.Pd)(a,b,c,e,f);
q.dynCall_iijjiii=(a,b,c,e,f,h,l,p,t)=>(q.dynCall_iijjiii=Z.Qd)(a,b,c,e,f,h,l,p,t);q.dynCall_iij=(a,b,c,e)=>(q.dynCall_iij=Z.Rd)(a,b,c,e);q.dynCall_vijjjii=(a,b,c,e,f,h,l,p,t,v)=>(q.dynCall_vijjjii=Z.Sd)(a,b,c,e,f,h,l,p,t,v);q.dynCall_jiji=(a,b,c,e,f)=>(q.dynCall_jiji=Z.Td)(a,b,c,e,f);q.dynCall_viijii=(a,b,c,e,f,h,l)=>(q.dynCall_viijii=Z.Ud)(a,b,c,e,f,h,l);q.dynCall_iiiiij=(a,b,c,e,f,h,l)=>(q.dynCall_iiiiij=Z.Vd)(a,b,c,e,f,h,l);
q.dynCall_iiiiijj=(a,b,c,e,f,h,l,p,t)=>(q.dynCall_iiiiijj=Z.Wd)(a,b,c,e,f,h,l,p,t);q.dynCall_iiiiiijj=(a,b,c,e,f,h,l,p,t,v)=>(q.dynCall_iiiiiijj=Z.Xd)(a,b,c,e,f,h,l,p,t,v);function Sd(a,b,c,e,f){var h=Zd();try{O.get(a)(b,c,e,f)}catch(l){Yd(h);if(l!==l+0)throw l;Xd(1,0)}}function Jd(a,b,c){var e=Zd();try{return O.get(a)(b,c)}catch(f){Yd(e);if(f!==f+0)throw f;Xd(1,0)}}function Qd(a,b,c){var e=Zd();try{O.get(a)(b,c)}catch(f){Yd(e);if(f!==f+0)throw f;Xd(1,0)}}
function Id(a,b){var c=Zd();try{return O.get(a)(b)}catch(e){Yd(c);if(e!==e+0)throw e;Xd(1,0)}}function Pd(a,b){var c=Zd();try{O.get(a)(b)}catch(e){Yd(c);if(e!==e+0)throw e;Xd(1,0)}}function Kd(a,b,c,e){var f=Zd();try{return O.get(a)(b,c,e)}catch(h){Yd(f);if(h!==h+0)throw h;Xd(1,0)}}function Vd(a,b,c,e,f,h,l,p,t,v){var y=Zd();try{O.get(a)(b,c,e,f,h,l,p,t,v)}catch(C){Yd(y);if(C!==C+0)throw C;Xd(1,0)}}function Rd(a,b,c,e){var f=Zd();try{O.get(a)(b,c,e)}catch(h){Yd(f);if(h!==h+0)throw h;Xd(1,0)}}
function Ud(a,b,c,e,f,h,l){var p=Zd();try{O.get(a)(b,c,e,f,h,l)}catch(t){Yd(p);if(t!==t+0)throw t;Xd(1,0)}}function Nd(a,b,c,e,f,h,l,p){var t=Zd();try{return O.get(a)(b,c,e,f,h,l,p)}catch(v){Yd(t);if(v!==v+0)throw v;Xd(1,0)}}function Td(a,b,c,e,f,h){var l=Zd();try{O.get(a)(b,c,e,f,h)}catch(p){Yd(l);if(p!==p+0)throw p;Xd(1,0)}}function Ld(a,b,c,e,f){var h=Zd();try{return O.get(a)(b,c,e,f)}catch(l){Yd(h);if(l!==l+0)throw l;Xd(1,0)}}
function Od(a,b,c,e,f,h,l,p,t,v){var y=Zd();try{return O.get(a)(b,c,e,f,h,l,p,t,v)}catch(C){Yd(y);if(C!==C+0)throw C;Xd(1,0)}}function Md(a,b,c,e,f,h,l){var p=Zd();try{return O.get(a)(b,c,e,f,h,l)}catch(t){Yd(p);if(t!==t+0)throw t;Xd(1,0)}}var $d,ae;Oa=function be(){$d||ce();$d||(Oa=be)};function ce(){if(!(0<La)){if(!ae&&(ae=1,Wa(Ia),0<La))return;$d||($d=1,q.calledRun=1,Aa||(Wa(Ja),aa(q),q.onRuntimeInitialized?.(),Wa(Ka)))}}ce();moduleRtn=ea;


  return moduleRtn;
}
);
})();
export default CanvasKitInit;
